  !Zhang-Buren-Li PES(2024)
  !3D Potential Energy Surface of Li3 system
  !Input variable: r1,r2,r3 (three bond distances in bohr)
  !Output: v (potential energy in hartree)

  subroutine pot_li3(r1,r2,r3,v)
  implicit none
  real*8,intent(in) :: r1,r2,r3
  real*8,intent(out) :: v
  real*8,external :: fcut
  real*8,parameter :: vmax=0.03d0
  real*8 :: pi,vsr,vlr,x(3),f(3),dv(3),alf,z,r,cost,fac
  real*8 :: rr1,rr2,rr3,rrt

  pi=dacos(-1.d0)
  
  !Vcut
  if (min(r1,r2,r3) .lt. 3.9d0 .or. min(r1,r2,r3) .gt. 8.d0)then
    v=vmax
    return
  endif

  !Short range
  x(1)=1.d0/r1
  x(2)=1.d0/r2
  x(3)=1.d0/r3
  f(1)=x(1)+x(2)+x(3)
  f(2)=dsqrt(x(1)*x(1)+x(2)*x(2)+x(3)*x(3))
  f(3)=(x(1)**3+x(2)**3+x(3)**3)**(1.d0/3.d0)
  call potsr_li3(f,vsr,0,dv)

  !Long range
  rr1=r1
  rr2=r2
  rr3=r3
  if(rr1 .lt. rr2)then
    rrt=rr2
    rr2=rr1
    rr1=rrt
  endif
  if(rr3 .lt. rr2)then
    rrt=rr2
    rr2=rr3
    rr3=rrt
  endif
  !trans bonds to Jacobi
  alf=0.5d0
  z=dsqrt((1.d0-alf)*rr1*rr1+(alf*alf-alf)*rr2*rr2+alf*rr3*rr3)
  r=rr2
  cost=(rr1*rr1+rr2*rr2-rr3*rr3)/(2.d0*rr1*rr2)
  call potlr_li_li2(z,r,cost,vlr)
  
  !Connect
  fac=fcut(22.d0,2.d0,z)
  v=fac*vsr+(1.d0-fac)*vlr

  v=min(v,vmax)

  return
  end subroutine

  function fcut(x0,delt,x)
  implicit none
  real*8 :: x0,delt,x,fcut
  fcut=0.5d0-0.5d0*dtanh((x-x0)/delt)
  return
  end function

  subroutine potlr_li_li2(z,r,cost,v)
  implicit none
  real*8,intent(in) :: z,r,cost
  real*8,intent(out) :: v
  real*8 :: polli,ionli,polyli2,polzli2,ionli2,vdisp,vli2
  real*8 :: voptg=0.434699266080d0
  real*8 :: fac
  real*8 :: dv(3)
 
  !polarizability of Li
   polli=165.09246072d0
  !ionization energy of Li 
  ionli=0.19809291d0
  !excitation energy of Li2 (X --> A)
  ionli2=0.06371177857d0
  !perpendicular polarizability of Li2
  call poly_li2(r,polyli2,0,dv)
  !parallel polarizability of Li2
  call polz_li2(r,polzli2,0,dv)

  !dispersion energy
  fac=0.5d0*ionli*ionli2*polli/(ionli+ionli2)/z**6
  vdisp=-fac*(2.d0*polyli2+polzli2+(polzli2-polyli2)*(1.5d0*cost**2-0.5d0))

  !diatom energy
  call pot_li2(r,vli2,0,dv)

  !total long-range energy
  v=vdisp+vli2+voptg

  return
  end subroutine

  subroutine pot_li2(r,v,idg,dv)
  implicit none
  integer,parameter :: nnlr =   2
  integer,parameter :: nin =   1
  integer,parameter :: nout =   1
  integer,parameter :: nnmx =  20
  real*8,intent(in) :: r(nin)
  integer,intent(in) :: idg
  real*8,intent(out) :: v(nout),dv(nout,nin)
  integer :: nnst(0:300)
  real*8,allocatable :: xmin(:),xmax(:),ymin(:),ymax(:)
  real*8,allocatable :: ws(:,:,:),bs(:,:)
  real*8,allocatable :: as(:,:),das(:,:,:)
  integer :: i,j,k,m
  real*8 :: an,y,dy,ns,dns
  allocate(xmin(nin),xmax(nin),ymin(nout),ymax(nout))
  allocate(ws(nnmx,nnmx,nnlr),bs(nnmx,nnlr))
  allocate(as(nnmx,0:nnlr),das(nnmx,nin,0:nnlr))
  nnst(  0) =   1
  nnst(  1) =  20
  nnst(  2) =   1
  xmin(  1) =             3.5000000000000000
  xmax(  1) =             8.0399999999999991
  ymin(  1) =            -0.4346993685920000
  ymax(  1) =            -0.4004110475670000
  ws(  1,  1,  1) =            -1.4191565601059899
  ws(  2,  1,  1) =            -2.3082788872377802
  ws(  3,  1,  1) =            -0.0153656015866152
  ws(  4,  1,  1) =            -0.9427655331709190
  ws(  5,  1,  1) =             2.0421384960871301
  ws(  6,  1,  1) =            -0.0049183915187966
  ws(  7,  1,  1) =             1.1508553351419799
  ws(  8,  1,  1) =            -1.2007315024341900
  ws(  9,  1,  1) =             0.7889677791895690
  ws( 10,  1,  1) =             0.0163914206378931
  ws( 11,  1,  1) =            -1.1307532017174799
  ws( 12,  1,  1) =             0.0023854026752467
  ws( 13,  1,  1) =             0.0916425687674274
  ws( 14,  1,  1) =            -0.5806641504898740
  ws( 15,  1,  1) =             0.4765117599217480
  ws( 16,  1,  1) =            -0.7575379262694000
  ws( 17,  1,  1) =             0.0068754084876741
  ws( 18,  1,  1) =            -0.8913286602974210
  ws( 19,  1,  1) =             0.0018784335576906
  ws( 20,  1,  1) =             1.5688762881898899
  ws(  1,  1,  2) =            -0.8805982888516370
  ws(  1,  2,  2) =             2.6464984664564999
  ws(  1,  3,  2) =             0.8603239038015330
  ws(  1,  4,  2) =            -0.6884923034920570
  ws(  1,  5,  2) =            -2.2906852357662300
  ws(  1,  6,  2) =            -1.6738962840225500
  ws(  1,  7,  2) =            -1.4309162677795999
  ws(  1,  8,  2) =            -0.3346886157656920
  ws(  1,  9,  2) =             0.8326662105935750
  ws(  1, 10,  2) =            -0.9075265251629920
  ws(  1, 11,  2) =            -0.6530797976899300
  ws(  1, 12,  2) =             1.8224775390324299
  ws(  1, 13,  2) =            -0.3761950086005920
  ws(  1, 14,  2) =             0.6966639159506730
  ws(  1, 15,  2) =            -0.1256776853381930
  ws(  1, 16,  2) =             0.5029448655815240
  ws(  1, 17,  2) =            -1.0947323448274500
  ws(  1, 18,  2) =            -0.2709493733688410
  ws(  1, 19,  2) =             1.4343888878691400
  ws(  1, 20,  2) =            -1.6237333146473500
  bs(  1,  1) =            -1.1499962194064099
  bs(  2,  1) =            -3.3534365981121201
  bs(  3,  1) =             0.8238263363211320
  bs(  4,  1) =             0.3145667711841130
  bs(  5,  1) =             2.9170691284677899
  bs(  6,  1) =            -1.0838408209124999
  bs(  7,  1) =             1.1215233431739600
  bs(  8,  1) =            -0.1316087985171660
  bs(  9,  1) =            -0.5849348836760040
  bs( 10,  1) =            -0.9844595910407180
  bs( 11,  1) =            -0.4508089601614120
  bs( 12,  1) =             1.2920404630716000
  bs( 13,  1) =             1.8741700618399499
  bs( 14,  1) =            -0.3013206833407840
  bs( 15,  1) =            -1.0226589295058399
  bs( 16,  1) =            -0.6391472658456530
  bs( 17,  1) =            -0.9738797054132510
  bs( 18,  1) =             0.2305503815039470
  bs( 19,  1) =             0.9986743378038320
  bs( 20,  1) =             1.6718786214331800
  bs(  1,  2) =             1.1235019409475000
  do i=1,nnst(0)
    as(i,0)=(r(i)-xmin(i))/(xmax(i)-xmin(i))*2.d0-1.d0
  enddo
  das=0.d0
  do i=1,nnst(0)
    das(i,i,0)=1.d0
  enddo
  do m=1,nnlr
    do i=1,nnst(m)
      an=0.d0
      do j=1,nnst(m-1)
        an=an+ws(i,j,m)*as(j,m-1)
      enddo
      ns=an+bs(i,m)
      if (m .lt. nnlr)then
        call nn_tranf(ns,y)
        as(i,m)=y
      else
        as(i,m)=ns
      endif
      if (idg .eq. 1)then
        do j=1,nnst(0)
          an=0.d0
          do k=1,nnst(m-1)
            an=an+ws(i,k,m)*das(k,j,m-1)
          enddo
          dns=an
          if (m .lt. nnlr)then
            call nn_dtranf(ns,dy)
            das(i,j,m)=dy*dns
          else
            das(i,j,m)=dns
          endif
        enddo
      endif
    enddo
  enddo
  do i=1,nnst(nnlr)
    v(i)=(as(i,nnlr)+1.d0)*(ymax(i)-ymin(i))/2.d0+ymin(i)
  enddo
  if (idg .eq. 1)then
    do j=1,nnst(0)
      do i=1,nnst(nnlr)
        dv(i,j)=das(i,j,nnlr)*(ymax(i)-ymin(i))/(xmax(j)-xmin(j))
      enddo
    enddo
  endif
  return
  end subroutine

  subroutine poly_li2(r,v,idg,dv)
  implicit none
  integer,parameter :: nnlr =   2
  integer,parameter :: nin =   1
  integer,parameter :: nout =   1
  integer,parameter :: nnmx =  20
  real*8,intent(in) :: r(nin)
  integer,intent(in) :: idg
  real*8,intent(out) :: v(nout),dv(nout,nin)
  integer :: nnst(0:300)
  real*8,allocatable :: xmin(:),xmax(:),ymin(:),ymax(:)
  real*8,allocatable :: ws(:,:,:),bs(:,:)
  real*8,allocatable :: as(:,:),das(:,:,:)
  integer :: i,j,k,m
  real*8 :: an,y,dy,ns,dns
  allocate(xmin(nin),xmax(nin),ymin(nout),ymax(nout))
  allocate(ws(nnmx,nnmx,nnlr),bs(nnmx,nnlr))
  allocate(as(nnmx,0:nnlr),das(nnmx,nin,0:nnlr))
  nnst(  0) =   1
  nnst(  1) =  20
  nnst(  2) =   1
  xmin(  1) =             3.5000000000000000
  xmax(  1) =             8.0199999999999996
  ymin(  1) =           122.5523165999999975
  ymax(  1) =           247.4534438000000023
  ws(  1,  1,  1) =             0.6391369072974250
  ws(  2,  1,  1) =             0.0989603369520272
  ws(  3,  1,  1) =             0.4624812730837260
  ws(  4,  1,  1) =             0.2321629571645550
  ws(  5,  1,  1) =            -0.1907041159049600
  ws(  6,  1,  1) =            -1.8452991740518601
  ws(  7,  1,  1) =            -1.1037436371840099
  ws(  8,  1,  1) =             0.6865258189849850
  ws(  9,  1,  1) =            -0.8574246843590910
  ws( 10,  1,  1) =            -3.0640617674626101
  ws( 11,  1,  1) =            -0.0567134458288914
  ws( 12,  1,  1) =            -0.9811602824130200
  ws( 13,  1,  1) =            -0.2515284862669280
  ws( 14,  1,  1) =             0.6335564305189930
  ws( 15,  1,  1) =             0.2613455627113300
  ws( 16,  1,  1) =            -0.1759316739069870
  ws( 17,  1,  1) =             1.0376268395453700
  ws( 18,  1,  1) =            -2.6003215816243399
  ws( 19,  1,  1) =             0.6633943721831350
  ws( 20,  1,  1) =            -0.1206543890632930
  ws(  1,  1,  2) =            -0.2134616312504370
  ws(  1,  2,  2) =            -0.1363710164188010
  ws(  1,  3,  2) =            -0.5382001614986140
  ws(  1,  4,  2) =            -0.2604476311953460
  ws(  1,  5,  2) =             0.8541394464194920
  ws(  1,  6,  2) =            -1.3560178636616700
  ws(  1,  7,  2) =            -0.1996051061174430
  ws(  1,  8,  2) =            -0.4848710087773740
  ws(  1,  9,  2) =            -0.3549785633911690
  ws(  1, 10,  2) =            -0.4126610134062330
  ws(  1, 11,  2) =            -0.6542742619820500
  ws(  1, 12,  2) =             0.2052534813707330
  ws(  1, 13,  2) =             0.5628223259921350
  ws(  1, 14,  2) =             0.4767970762423930
  ws(  1, 15,  2) =             0.8318897579689440
  ws(  1, 16,  2) =             0.4022633438359970
  ws(  1, 17,  2) =             0.3713508475099530
  ws(  1, 18,  2) =             1.0887712327353700
  ws(  1, 19,  2) =             0.8495345271492660
  ws(  1, 20,  2) =            -0.5962735072760880
  bs(  1,  1) =            -0.1300874735038780
  bs(  2,  1) =             0.3600150091295680
  bs(  3,  1) =             0.7982875293321980
  bs(  4,  1) =            -0.7780509968606910
  bs(  5,  1) =             0.7348904197728900
  bs(  6,  1) =            -1.4532291226589000
  bs(  7,  1) =            -0.0281047186495074
  bs(  8,  1) =             0.6974449200029780
  bs(  9,  1) =             0.0739622367887539
  bs( 10,  1) =            -1.9960495368094500
  bs( 11,  1) =            -0.7603345233920960
  bs( 12,  1) =             0.4955667213747260
  bs( 13,  1) =             0.6358933182397050
  bs( 14,  1) =            -0.7639982885793820
  bs( 15,  1) =            -0.1180376245988910
  bs( 16,  1) =             0.5500849327072560
  bs( 17,  1) =            -0.3232286541561270
  bs( 18,  1) =            -1.7874961480931899
  bs( 19,  1) =            -0.6021788023650770
  bs( 20,  1) =             0.8977888240812920
  bs(  1,  2) =            -0.2261232416484180
  do i=1,nnst(0)
    as(i,0)=(r(i)-xmin(i))/(xmax(i)-xmin(i))*2.d0-1.d0
  enddo
  das=0.d0
  do i=1,nnst(0)
    das(i,i,0)=1.d0
  enddo
  do m=1,nnlr
    do i=1,nnst(m)
      an=0.d0
      do j=1,nnst(m-1)
        an=an+ws(i,j,m)*as(j,m-1)
      enddo
      ns=an+bs(i,m)
      if (m .lt. nnlr)then
        call nn_tranf(ns,y)
        as(i,m)=y
      else
        as(i,m)=ns
      endif
      if (idg .eq. 1)then
        do j=1,nnst(0)
          an=0.d0
          do k=1,nnst(m-1)
            an=an+ws(i,k,m)*das(k,j,m-1)
          enddo
          dns=an
          if (m .lt. nnlr)then
            call nn_dtranf(ns,dy)
            das(i,j,m)=dy*dns
          else
            das(i,j,m)=dns
          endif
        enddo
      endif
    enddo
  enddo
  do i=1,nnst(nnlr)
    v(i)=(as(i,nnlr)+1.d0)*(ymax(i)-ymin(i))/2.d0+ymin(i)
  enddo
  if (idg .eq. 1)then
    do j=1,nnst(0)
      do i=1,nnst(nnlr)
        dv(i,j)=das(i,j,nnlr)*(ymax(i)-ymin(i))/(xmax(j)-xmin(j))
      enddo
    enddo
  endif
  return
  end subroutine

  subroutine polz_li2(r,v,idg,dv)
  implicit none
  integer,parameter :: nnlr =   2
  integer,parameter :: nin =   1
  integer,parameter :: nout =   1
  integer,parameter :: nnmx =  20
  real*8,intent(in) :: r(nin)
  integer,intent(in) :: idg
  real*8,intent(out) :: v(nout),dv(nout,nin)
  integer :: nnst(0:300)
  real*8,allocatable :: xmin(:),xmax(:),ymin(:),ymax(:)
  real*8,allocatable :: ws(:,:,:),bs(:,:)
  real*8,allocatable :: as(:,:),das(:,:,:)
  integer :: i,j,k,m
  real*8 :: an,y,dy,ns,dns
  allocate(xmin(nin),xmax(nin),ymin(nout),ymax(nout))
  allocate(ws(nnmx,nnmx,nnlr),bs(nnmx,nnlr))
  allocate(as(nnmx,0:nnlr),das(nnmx,nin,0:nnlr))
  nnst(  0) =   1
  nnst(  1) =  20
  nnst(  2) =   1
  xmin(  1) =             3.5000000000000000
  xmax(  1) =             8.0199999999999996
  ymin(  1) =           170.1866673000000105
  ymax(  1) =           645.3405741999999918
  ws(  1,  1,  1) =            -0.0641890073115312
  ws(  2,  1,  1) =            -0.1652108786959310
  ws(  3,  1,  1) =             0.0555153669621156
  ws(  4,  1,  1) =             0.9272771988249940
  ws(  5,  1,  1) =            -0.7276134330831850
  ws(  6,  1,  1) =             2.3604726297525702
  ws(  7,  1,  1) =            -0.4274981516255500
  ws(  8,  1,  1) =            -1.1033162375787600
  ws(  9,  1,  1) =             1.9455398439302301
  ws( 10,  1,  1) =             0.8758708384279680
  ws( 11,  1,  1) =            -1.4347061691970500
  ws( 12,  1,  1) =             0.0720022381348490
  ws( 13,  1,  1) =            -2.9581078949409099
  ws( 14,  1,  1) =            -0.8209504172171050
  ws( 15,  1,  1) =             0.8250478684142590
  ws( 16,  1,  1) =             0.6278788409697980
  ws( 17,  1,  1) =             0.9776445247266510
  ws( 18,  1,  1) =             0.0951115040167771
  ws( 19,  1,  1) =             0.9003294361138360
  ws( 20,  1,  1) =             0.0573822181592746
  ws(  1,  1,  2) =             0.8994345853086760
  ws(  1,  2,  2) =            -0.1071173025987260
  ws(  1,  3,  2) =            -0.7961611027936540
  ws(  1,  4,  2) =            -1.0462733270559901
  ws(  1,  5,  2) =            -0.4605923376845000
  ws(  1,  6,  2) =             1.3191779064912501
  ws(  1,  7,  2) =             0.1116819839693760
  ws(  1,  8,  2) =             1.1757600434154101
  ws(  1,  9,  2) =             0.7991595606099871
  ws(  1, 10,  2) =            -0.9112316794601100
  ws(  1, 11,  2) =            -0.8866357769806660
  ws(  1, 12,  2) =            -0.8169650456504730
  ws(  1, 13,  2) =            -0.2890323500817630
  ws(  1, 14,  2) =             0.1679359027549220
  ws(  1, 15,  2) =            -0.5415000886323420
  ws(  1, 16,  2) =            -0.6358898999395320
  ws(  1, 17,  2) =             0.7995167228550680
  ws(  1, 18,  2) =            -0.8691777817954111
  ws(  1, 19,  2) =            -0.0827389094949310
  ws(  1, 20,  2) =            -0.6406603696394449
  bs(  1,  1) =            -0.7163147682330850
  bs(  2,  1) =             1.0072397238812800
  bs(  3,  1) =             0.7229119343805840
  bs(  4,  1) =            -1.0306223737398399
  bs(  5,  1) =            -0.0268097146466856
  bs(  6,  1) =            -2.4276872660584701
  bs(  7,  1) =             0.1595467879255190
  bs(  8,  1) =             1.2990446242502101
  bs(  9,  1) =            -0.6889170168244980
  bs( 10,  1) =            -0.9892808513814630
  bs( 11,  1) =            -0.0743994452052646
  bs( 12,  1) =             0.5272802674705970
  bs( 13,  1) =             1.7743249148662299
  bs( 14,  1) =            -0.3266952175555440
  bs( 15,  1) =            -1.0296347238374099
  bs( 16,  1) =            -0.6575786786187390
  bs( 17,  1) =             0.7072382463877011
  bs( 18,  1) =             0.3025659815332960
  bs( 19,  1) =             0.3476149199573260
  bs( 20,  1) =             0.6515177609452530
  bs(  1,  2) =             0.3325855384471110
  do i=1,nnst(0)
    as(i,0)=(r(i)-xmin(i))/(xmax(i)-xmin(i))*2.d0-1.d0
  enddo
  das=0.d0
  do i=1,nnst(0)
    das(i,i,0)=1.d0
  enddo
  do m=1,nnlr
    do i=1,nnst(m)
      an=0.d0
      do j=1,nnst(m-1)
        an=an+ws(i,j,m)*as(j,m-1)
      enddo
      ns=an+bs(i,m)
      if (m .lt. nnlr)then
        call nn_tranf(ns,y)
        as(i,m)=y
      else
        as(i,m)=ns
      endif
      if (idg .eq. 1)then
        do j=1,nnst(0)
          an=0.d0
          do k=1,nnst(m-1)
            an=an+ws(i,k,m)*das(k,j,m-1)
          enddo
          dns=an
          if (m .lt. nnlr)then
            call nn_dtranf(ns,dy)
            das(i,j,m)=dy*dns
          else
            das(i,j,m)=dns
          endif
        enddo
      endif
    enddo
  enddo
  do i=1,nnst(nnlr)
    v(i)=(as(i,nnlr)+1.d0)*(ymax(i)-ymin(i))/2.d0+ymin(i)
  enddo
  if (idg .eq. 1)then
    do j=1,nnst(0)
      do i=1,nnst(nnlr)
        dv(i,j)=das(i,j,nnlr)*(ymax(i)-ymin(i))/(xmax(j)-xmin(j))
      enddo
    enddo
  endif
  return
  end subroutine

  subroutine potsr_li3(r,v,idg,dv)
  implicit none
  integer,parameter :: nnlr =   3
  integer,parameter :: nin =   3
  integer,parameter :: nout =   1
  integer,parameter :: nnmx =  50
  real*8,intent(in) :: r(nin)
  integer,intent(in) :: idg
  real*8,intent(out) :: v(nout),dv(nout,nin)
  integer :: nnst(0:300)
  real*8,allocatable :: xmin(:),xmax(:),ymin(:),ymax(:)
  real*8,allocatable :: ws(:,:,:),bs(:,:)
  real*8,allocatable :: as(:,:),das(:,:,:)
  integer :: i,j,k,m
  real*8 :: an,y,dy,ns,dns
  allocate(xmin(nin),xmax(nin),ymin(nout),ymax(nout))
  allocate(ws(nnmx,nnmx,nnlr),bs(nnmx,nnlr))
  allocate(as(nnmx,0:nnlr),das(nnmx,nin,0:nnlr))
  nnst(  0) =   3
  nnst(  1) =  50
  nnst(  2) =  50
  nnst(  3) =   1
  xmin(  1) =             0.1833659570390960
  xmax(  1) =             0.6698654963904730
  xmin(  2) =             0.1327979318142070
  xmax(  2) =             0.3894068692991410
  xmin(  3) =             0.1252024875156390
  xmax(  3) =             0.3263202766092790
  ymin(  1) =            -0.0223296500000000
  ymax(  1) =             0.0330632900000000
  ws(  1,  1,  1) =             1.3685522006893200
  ws(  2,  1,  1) =            -0.9285670008859730
  ws(  3,  1,  1) =            -1.1871577010716301
  ws(  4,  1,  1) =            -1.5640709576885401
  ws(  5,  1,  1) =            -1.3372501526451099
  ws(  6,  1,  1) =            -1.7165364740938400
  ws(  7,  1,  1) =             0.2521562628962550
  ws(  8,  1,  1) =             1.3393173927853901
  ws(  9,  1,  1) =             0.2557809772984270
  ws( 10,  1,  1) =             0.4198739752737770
  ws( 11,  1,  1) =             0.6504109864088190
  ws( 12,  1,  1) =            -0.2623316356533180
  ws( 13,  1,  1) =             2.0790189846845100
  ws( 14,  1,  1) =             0.2276370095270580
  ws( 15,  1,  1) =             3.1903784316583499
  ws( 16,  1,  1) =             2.0549722147057401
  ws( 17,  1,  1) =            -0.0135878571363400
  ws( 18,  1,  1) =             5.7422252711296702
  ws( 19,  1,  1) =             2.0360739586228598
  ws( 20,  1,  1) =            -2.3422715982274802
  ws( 21,  1,  1) =             3.2938384084305299
  ws( 22,  1,  1) =            -1.2112165617203701
  ws( 23,  1,  1) =             3.7457725518121499
  ws( 24,  1,  1) =             2.6749768606704101
  ws( 25,  1,  1) =             1.1672926399506900
  ws( 26,  1,  1) =            -0.5451629585033470
  ws( 27,  1,  1) =            -0.8173876029572510
  ws( 28,  1,  1) =            -0.1221648812076480
  ws( 29,  1,  1) =             0.6891473598662859
  ws( 30,  1,  1) =            -1.9627359203244701
  ws( 31,  1,  1) =            -0.8053284379838320
  ws( 32,  1,  1) =            -2.0643470291005501
  ws( 33,  1,  1) =             1.9511521325271799
  ws( 34,  1,  1) =             0.9055828317811651
  ws( 35,  1,  1) =            -0.0677929525655599
  ws( 36,  1,  1) =             3.4851950077758098
  ws( 37,  1,  1) =             2.9400872996077201
  ws( 38,  1,  1) =            -4.8359546585161297
  ws( 39,  1,  1) =             2.0642081427558998
  ws( 40,  1,  1) =             0.9236742209403300
  ws( 41,  1,  1) =             0.3016914901134270
  ws( 42,  1,  1) =            -1.1218705237973601
  ws( 43,  1,  1) =            -0.2778573090391800
  ws( 44,  1,  1) =            -1.9284075624823400
  ws( 45,  1,  1) =            -0.8729056126140970
  ws( 46,  1,  1) =            -1.1702556721354700
  ws( 47,  1,  1) =             2.8081925327956201
  ws( 48,  1,  1) =            -0.9576095232852680
  ws( 49,  1,  1) =             1.5303323115490099
  ws( 50,  1,  1) =             9.9891268574100494
  ws(  1,  2,  1) =            -1.5774429513004800
  ws(  2,  2,  1) =             4.2370411577277700
  ws(  3,  2,  1) =             2.4083067575639299
  ws(  4,  2,  1) =            -0.3180781539646890
  ws(  5,  2,  1) =             2.4228850299643199
  ws(  6,  2,  1) =             0.0348916785308441
  ws(  7,  2,  1) =             0.4535381679749270
  ws(  8,  2,  1) =            -0.2179794900432030
  ws(  9,  2,  1) =             0.7540110659267630
  ws( 10,  2,  1) =             0.2114764768964130
  ws( 11,  2,  1) =            -2.1163778546151399
  ws( 12,  2,  1) =             1.5471057299300199
  ws( 13,  2,  1) =             0.4929946056937800
  ws( 14,  2,  1) =            -2.0937425721324598
  ws( 15,  2,  1) =            -2.5408087821876602
  ws( 16,  2,  1) =             4.4253722863523004
  ws( 17,  2,  1) =             2.9857656866190201
  ws( 18,  2,  1) =            -5.1188201447578603
  ws( 19,  2,  1) =             0.4278883859492880
  ws( 20,  2,  1) =             2.2085979472050199
  ws( 21,  2,  1) =            -0.1063325712914690
  ws( 22,  2,  1) =            -4.3045044627390299
  ws( 23,  2,  1) =            -2.3092002365965598
  ws( 24,  2,  1) =            -1.0254295877148001
  ws( 25,  2,  1) =            -0.1444747536098190
  ws( 26,  2,  1) =             1.1195809454513499
  ws( 27,  2,  1) =             3.1065755886870501
  ws( 28,  2,  1) =            -2.6313976382592998
  ws( 29,  2,  1) =             4.1719253589481697
  ws( 30,  2,  1) =            -3.9105364319753999
  ws( 31,  2,  1) =            -1.1816234054080501
  ws( 32,  2,  1) =             0.0482839103539471
  ws( 33,  2,  1) =            -1.0647593057871301
  ws( 34,  2,  1) =            -2.2624619499712399
  ws( 35,  2,  1) =            -0.1668817722936490
  ws( 36,  2,  1) =            -1.1887636551547400
  ws( 37,  2,  1) =            -4.1054696284899101
  ws( 38,  2,  1) =             3.5995553968349800
  ws( 39,  2,  1) =            -3.4206038845540099
  ws( 40,  2,  1) =             0.8382465285400640
  ws( 41,  2,  1) =             0.4809754562285660
  ws( 42,  2,  1) =            -1.3531303956118399
  ws( 43,  2,  1) =             2.7928240489175602
  ws( 44,  2,  1) =             4.1069611144516900
  ws( 45,  2,  1) =             3.1938239098541699
  ws( 46,  2,  1) =             2.2034839755281599
  ws( 47,  2,  1) =            -2.8076773754761200
  ws( 48,  2,  1) =             1.5850765270629401
  ws( 49,  2,  1) =            -2.8935696754370901
  ws( 50,  2,  1) =            -0.6843636964950210
  ws(  1,  3,  1) =            -1.5317555464297199
  ws(  2,  3,  1) =            -3.0048583012304801
  ws(  3,  3,  1) =             0.5282594651422871
  ws(  4,  3,  1) =            -0.1236179902097510
  ws(  5,  3,  1) =            -0.8587296731362610
  ws(  6,  3,  1) =            -0.6994334723917590
  ws(  7,  3,  1) =            -0.3875084771145850
  ws(  8,  3,  1) =            -0.5143222130106450
  ws(  9,  3,  1) =            -0.1524943668351790
  ws( 10,  3,  1) =             0.3329800438292680
  ws( 11,  3,  1) =             0.7366054899897760
  ws( 12,  3,  1) =            -3.5049856661637002
  ws( 13,  3,  1) =            -1.6741179810320601
  ws( 14,  3,  1) =             3.7251844632037399
  ws( 15,  3,  1) =             0.4893849737365530
  ws( 16,  3,  1) =            -4.3503491610004597
  ws( 17,  3,  1) =            -3.9745256756360501
  ws( 18,  3,  1) =            -0.5345986510977170
  ws( 19,  3,  1) =            -0.8343455395402080
  ws( 20,  3,  1) =            -0.2822448797122580
  ws( 21,  3,  1) =            -2.6598091639690900
  ws( 22,  3,  1) =             3.4719092290605800
  ws( 23,  3,  1) =            -0.6070350931334640
  ws( 24,  3,  1) =            -1.2202963239331699
  ws( 25,  3,  1) =             0.8672406006278380
  ws( 26,  3,  1) =            -1.8703656049915900
  ws( 27,  3,  1) =            -2.5836506226578901
  ws( 28,  3,  1) =             0.8271851039951990
  ws( 29,  3,  1) =            -5.2239892596057098
  ws( 30,  3,  1) =             5.6423952009601601
  ws( 31,  3,  1) =             1.2316748298228599
  ws( 32,  3,  1) =            -0.3344374518252560
  ws( 33,  3,  1) =            -1.0234945472794701
  ws( 34,  3,  1) =             1.2073676115018499
  ws( 35,  3,  1) =             0.1220293482029160
  ws( 36,  3,  1) =            -1.3027235559994399
  ws( 37,  3,  1) =             0.3884700273711630
  ws( 38,  3,  1) =            -0.6103588113961460
  ws( 39,  3,  1) =             1.5871807995152301
  ws( 40,  3,  1) =            -1.3230749301383400
  ws( 41,  3,  1) =            -0.6747946610266140
  ws( 42,  3,  1) =            -0.0685364935485362
  ws( 43,  3,  1) =            -2.2349609953618401
  ws( 44,  3,  1) =            -0.5364651832166820
  ws( 45,  3,  1) =            -2.1226770875775598
  ws( 46,  3,  1) =             0.3431803610365680
  ws( 47,  3,  1) =             0.5422400066365770
  ws( 48,  3,  1) =            -0.8686662215462490
  ws( 49,  3,  1) =             2.6639997019980601
  ws( 50,  3,  1) =            -8.3321719964811507
  ws(  1,  1,  2) =             0.1730310911731960
  ws(  2,  1,  2) =            -0.1923318426036480
  ws(  3,  1,  2) =            -0.0108421297661246
  ws(  4,  1,  2) =             0.4475406254330530
  ws(  5,  1,  2) =            -0.4379348695110880
  ws(  6,  1,  2) =            -0.1047964091999210
  ws(  7,  1,  2) =             0.4334069964475010
  ws(  8,  1,  2) =            -1.0617595801940001
  ws(  9,  1,  2) =             0.9373505409137890
  ws( 10,  1,  2) =             0.4094386631708420
  ws( 11,  1,  2) =             0.6274513409909150
  ws( 12,  1,  2) =             0.6985309293838070
  ws( 13,  1,  2) =             0.3973178552321180
  ws( 14,  1,  2) =             0.4256196713682390
  ws( 15,  1,  2) =            -0.3865815888926990
  ws( 16,  1,  2) =             0.9405635560456440
  ws( 17,  1,  2) =             1.2394738925794500
  ws( 18,  1,  2) =             0.2201383577235490
  ws( 19,  1,  2) =            -0.1962516214204450
  ws( 20,  1,  2) =            -0.5239166361957810
  ws( 21,  1,  2) =             1.0937321610212101
  ws( 22,  1,  2) =             0.0616985899042449
  ws( 23,  1,  2) =            -0.1378630865305880
  ws( 24,  1,  2) =            -0.2069104454767480
  ws( 25,  1,  2) =            -0.0464745779108821
  ws( 26,  1,  2) =             0.5526788398674800
  ws( 27,  1,  2) =             1.1447551393285400
  ws( 28,  1,  2) =             0.8024329756083080
  ws( 29,  1,  2) =            -0.8703542657848350
  ws( 30,  1,  2) =            -1.2229979414484100
  ws( 31,  1,  2) =             0.6040012177455441
  ws( 32,  1,  2) =             1.2988937704854999
  ws( 33,  1,  2) =            -0.9635223559383660
  ws( 34,  1,  2) =            -0.5767126333267260
  ws( 35,  1,  2) =             0.7072341653956390
  ws( 36,  1,  2) =            -0.0796949041641072
  ws( 37,  1,  2) =            -0.8308378281531990
  ws( 38,  1,  2) =            -0.0979103407983658
  ws( 39,  1,  2) =            -0.6658295544940510
  ws( 40,  1,  2) =             0.7638903719081690
  ws( 41,  1,  2) =             0.8309545251268160
  ws( 42,  1,  2) =            -0.2982390829893440
  ws( 43,  1,  2) =             1.1615241395520099
  ws( 44,  1,  2) =             0.2195880487710600
  ws( 45,  1,  2) =            -0.7107895987986040
  ws( 46,  1,  2) =             0.4753370631848830
  ws( 47,  1,  2) =             0.0337100206541984
  ws( 48,  1,  2) =             0.3156769419617060
  ws( 49,  1,  2) =            -0.9654299128943130
  ws( 50,  1,  2) =            -0.3529351474006080
  ws(  1,  2,  2) =            -1.0770700009680700
  ws(  2,  2,  2) =             0.9294105446103080
  ws(  3,  2,  2) =             0.1990481492535260
  ws(  4,  2,  2) =             0.8343906225175020
  ws(  5,  2,  2) =            -0.7342892381296240
  ws(  6,  2,  2) =            -0.4832143720516570
  ws(  7,  2,  2) =             0.2111703501057680
  ws(  8,  2,  2) =            -2.0360657898873602
  ws(  9,  2,  2) =             0.1060603279269100
  ws( 10,  2,  2) =            -0.4903453618699410
  ws( 11,  2,  2) =            -1.1336373133406401
  ws( 12,  2,  2) =             0.8115139453357690
  ws( 13,  2,  2) =            -0.4074594755829020
  ws( 14,  2,  2) =             1.2408935393058000
  ws( 15,  2,  2) =            -0.3346634523400360
  ws( 16,  2,  2) =            -0.1223609801524600
  ws( 17,  2,  2) =            -0.0961169610632976
  ws( 18,  2,  2) =            -0.8186136637151210
  ws( 19,  2,  2) =             0.8409889792059680
  ws( 20,  2,  2) =            -1.4081047040646399
  ws( 21,  2,  2) =            -2.3781566030433701
  ws( 22,  2,  2) =            -1.6570363220245199
  ws( 23,  2,  2) =            -0.6346454753198020
  ws( 24,  2,  2) =             0.6915461864133520
  ws( 25,  2,  2) =            -0.7252104973777280
  ws( 26,  2,  2) =             0.8268478366355519
  ws( 27,  2,  2) =             0.5644917597375370
  ws( 28,  2,  2) =            -0.1468976257519570
  ws( 29,  2,  2) =             0.2689373377741450
  ws( 30,  2,  2) =             0.5991076754728860
  ws( 31,  2,  2) =             0.7287203649439380
  ws( 32,  2,  2) =            -1.9103342369245699
  ws( 33,  2,  2) =             0.2718172517371730
  ws( 34,  2,  2) =             0.0383147205825168
  ws( 35,  2,  2) =            -1.3808101288337400
  ws( 36,  2,  2) =            -0.2560760391619170
  ws( 37,  2,  2) =            -1.4489089023544801
  ws( 38,  2,  2) =             0.1316953808062870
  ws( 39,  2,  2) =            -0.0852203522543395
  ws( 40,  2,  2) =            -2.5612924230426399
  ws( 41,  2,  2) =            -0.0369787475374239
  ws( 42,  2,  2) =             0.0678759361250779
  ws( 43,  2,  2) =            -1.3154100415870000
  ws( 44,  2,  2) =            -0.6037005231553770
  ws( 45,  2,  2) =             0.7779543992757920
  ws( 46,  2,  2) =             0.0980605185859736
  ws( 47,  2,  2) =             0.3089231888362110
  ws( 48,  2,  2) =            -0.1285492234754040
  ws( 49,  2,  2) =            -0.9301081496728600
  ws( 50,  2,  2) =             0.2747800577342520
  ws(  1,  3,  2) =            -0.8080180567236031
  ws(  2,  3,  2) =            -0.9532704122248040
  ws(  3,  3,  2) =             0.2038048673021450
  ws(  4,  3,  2) =            -0.9629671920851151
  ws(  5,  3,  2) =            -0.2956548523708100
  ws(  6,  3,  2) =             0.8689862875700300
  ws(  7,  3,  2) =            -0.9473141017650680
  ws(  8,  3,  2) =             1.3859289159683701
  ws(  9,  3,  2) =             0.8868090868942450
  ws( 10,  3,  2) =            -0.3671690073228010
  ws( 11,  3,  2) =            -0.5617188865800860
  ws( 12,  3,  2) =            -0.7332035705711880
  ws( 13,  3,  2) =             0.7438219991129060
  ws( 14,  3,  2) =             0.8008439574477350
  ws( 15,  3,  2) =             0.8267641362998520
  ws( 16,  3,  2) =             0.8300138995796810
  ws( 17,  3,  2) =             0.1963739987029020
  ws( 18,  3,  2) =            -0.2040049555468160
  ws( 19,  3,  2) =            -0.3826705346835750
  ws( 20,  3,  2) =            -1.5573066641233899
  ws( 21,  3,  2) =             0.3264515655058080
  ws( 22,  3,  2) =            -0.8272809097461690
  ws( 23,  3,  2) =            -0.5587990762462450
  ws( 24,  3,  2) =            -0.9812315805172340
  ws( 25,  3,  2) =            -0.9316492329554770
  ws( 26,  3,  2) =            -0.5616375286705160
  ws( 27,  3,  2) =            -0.4343247392963310
  ws( 28,  3,  2) =            -0.1986055575715480
  ws( 29,  3,  2) =             0.3840476494526910
  ws( 30,  3,  2) =             0.2656886217340250
  ws( 31,  3,  2) =            -0.3405033510823450
  ws( 32,  3,  2) =            -0.2632885322777270
  ws( 33,  3,  2) =            -0.1303470934781860
  ws( 34,  3,  2) =            -0.3374338455164220
  ws( 35,  3,  2) =            -0.0702299348040528
  ws( 36,  3,  2) =            -0.6485006146574580
  ws( 37,  3,  2) =            -0.2783263363733320
  ws( 38,  3,  2) =             0.6291428041671490
  ws( 39,  3,  2) =             0.1208424177780350
  ws( 40,  3,  2) =            -1.7276007630268899
  ws( 41,  3,  2) =            -0.5648403347713949
  ws( 42,  3,  2) =             1.0233941949581300
  ws( 43,  3,  2) =            -0.9146193111128190
  ws( 44,  3,  2) =            -0.5189468833223330
  ws( 45,  3,  2) =             1.0293605605034499
  ws( 46,  3,  2) =            -0.0537365047753109
  ws( 47,  3,  2) =            -0.7389130048170910
  ws( 48,  3,  2) =             0.1753434777979910
  ws( 49,  3,  2) =            -0.6946134585186420
  ws( 50,  3,  2) =            -0.4974020117154730
  ws(  1,  4,  2) =             0.2004416819150620
  ws(  2,  4,  2) =            -0.4862810223216070
  ws(  3,  4,  2) =            -0.8552766612856880
  ws(  4,  4,  2) =             0.4240448050359140
  ws(  5,  4,  2) =             0.3010420920256030
  ws(  6,  4,  2) =             1.0766868281854400
  ws(  7,  4,  2) =             0.3787090654914150
  ws(  8,  4,  2) =            -0.6445580447581000
  ws(  9,  4,  2) =             0.3399372837351390
  ws( 10,  4,  2) =             1.3046287689468801
  ws( 11,  4,  2) =             0.4769187782348300
  ws( 12,  4,  2) =             0.8019639920651720
  ws( 13,  4,  2) =            -0.3433869400922850
  ws( 14,  4,  2) =            -0.0050393055429106
  ws( 15,  4,  2) =             0.2568422776449870
  ws( 16,  4,  2) =             0.4580666181925000
  ws( 17,  4,  2) =             0.0563123922031579
  ws( 18,  4,  2) =            -0.8694732650640770
  ws( 19,  4,  2) =            -0.0663512249402875
  ws( 20,  4,  2) =            -1.1445272990185600
  ws( 21,  4,  2) =            -0.8166035886108680
  ws( 22,  4,  2) =            -0.3665506640463230
  ws( 23,  4,  2) =            -0.3775345774405370
  ws( 24,  4,  2) =            -1.1953107042993800
  ws( 25,  4,  2) =            -0.4143163477027410
  ws( 26,  4,  2) =             0.2789056624665050
  ws( 27,  4,  2) =             0.5972435996451250
  ws( 28,  4,  2) =             0.4972331211198550
  ws( 29,  4,  2) =            -0.2049118250904880
  ws( 30,  4,  2) =             0.0994100552617372
  ws( 31,  4,  2) =            -0.0394786806972737
  ws( 32,  4,  2) =            -0.3246093761326020
  ws( 33,  4,  2) =             0.5644517331546380
  ws( 34,  4,  2) =            -0.8699297160846630
  ws( 35,  4,  2) =             0.3528366704772990
  ws( 36,  4,  2) =             0.5932695501819510
  ws( 37,  4,  2) =            -0.3493375065690280
  ws( 38,  4,  2) =            -0.0186248476525072
  ws( 39,  4,  2) =             0.1040753049598760
  ws( 40,  4,  2) =             0.0553696902530933
  ws( 41,  4,  2) =            -0.4429340703024190
  ws( 42,  4,  2) =             0.6028304007875610
  ws( 43,  4,  2) =            -0.2453069171018400
  ws( 44,  4,  2) =            -0.6956512233003190
  ws( 45,  4,  2) =            -0.4366670912161120
  ws( 46,  4,  2) =             0.9373851233979810
  ws( 47,  4,  2) =             0.3750169897597570
  ws( 48,  4,  2) =            -0.8924436798247560
  ws( 49,  4,  2) =             0.0882362683951306
  ws( 50,  4,  2) =             0.5982043269468410
  ws(  1,  5,  2) =            -0.1973436244990150
  ws(  2,  5,  2) =             0.4661855023217210
  ws(  3,  5,  2) =            -0.4077149051290730
  ws(  4,  5,  2) =            -0.4721550072947100
  ws(  5,  5,  2) =             0.8599048177581580
  ws(  6,  5,  2) =            -0.5509257952484961
  ws(  7,  5,  2) =             0.8022100846358500
  ws(  8,  5,  2) =            -0.2071758542774780
  ws(  9,  5,  2) =            -0.5790141880367180
  ws( 10,  5,  2) =             0.1156902807288140
  ws( 11,  5,  2) =            -1.0648649751404600
  ws( 12,  5,  2) =             0.8604246677765990
  ws( 13,  5,  2) =            -0.6115713816442340
  ws( 14,  5,  2) =             0.3810886559869560
  ws( 15,  5,  2) =            -0.1985774084287090
  ws( 16,  5,  2) =             0.1218411730366190
  ws( 17,  5,  2) =             0.8404632258877510
  ws( 18,  5,  2) =             0.2074041443889510
  ws( 19,  5,  2) =             0.8131703197146580
  ws( 20,  5,  2) =            -1.0245144473416701
  ws( 21,  5,  2) =            -1.9843425588665999
  ws( 22,  5,  2) =            -0.7870549723777250
  ws( 23,  5,  2) =             0.7009173800021290
  ws( 24,  5,  2) =             1.1137527600346100
  ws( 25,  5,  2) =            -0.9206735528032099
  ws( 26,  5,  2) =            -0.6544572235878270
  ws( 27,  5,  2) =            -0.4595275458426320
  ws( 28,  5,  2) =             0.0308997121876742
  ws( 29,  5,  2) =             0.4960395496780280
  ws( 30,  5,  2) =            -0.1161766779292280
  ws( 31,  5,  2) =            -0.5873345592175180
  ws( 32,  5,  2) =            -1.1640390933021001
  ws( 33,  5,  2) =             0.7282564599312190
  ws( 34,  5,  2) =            -0.7103363505067890
  ws( 35,  5,  2) =             0.1557203236679670
  ws( 36,  5,  2) =            -0.6949625718591140
  ws( 37,  5,  2) =             0.1489310185261700
  ws( 38,  5,  2) =            -0.0543495617788318
  ws( 39,  5,  2) =             0.1266118749056480
  ws( 40,  5,  2) =            -0.6681921623804570
  ws( 41,  5,  2) =             1.0893152152502401
  ws( 42,  5,  2) =            -1.1122672820760300
  ws( 43,  5,  2) =            -0.9086868549400620
  ws( 44,  5,  2) =             0.6871761682751550
  ws( 45,  5,  2) =            -0.7350206786806260
  ws( 46,  5,  2) =            -0.4212108627430730
  ws( 47,  5,  2) =            -0.0044522906618713
  ws( 48,  5,  2) =            -0.1830221981707600
  ws( 49,  5,  2) =             0.4776705669494470
  ws( 50,  5,  2) =             0.2143279698973060
  ws(  1,  6,  2) =            -0.2015842027854020
  ws(  2,  6,  2) =             0.0735077344179046
  ws(  3,  6,  2) =             0.4552366043274330
  ws(  4,  6,  2) =             0.0452576822084784
  ws(  5,  6,  2) =            -0.6708454416016590
  ws(  6,  6,  2) =             0.3870698590561350
  ws(  7,  6,  2) =            -0.3528328409356730
  ws(  8,  6,  2) =            -0.0092448709296160
  ws(  9,  6,  2) =             0.0105668710811749
  ws( 10,  6,  2) =            -0.6583202942785840
  ws( 11,  6,  2) =             0.9025157906243551
  ws( 12,  6,  2) =             0.0839557441882285
  ws( 13,  6,  2) =            -0.9763303939023270
  ws( 14,  6,  2) =            -0.8129413594676580
  ws( 15,  6,  2) =             0.1851391292629420
  ws( 16,  6,  2) =             0.1600514470430980
  ws( 17,  6,  2) =            -0.0316858005027464
  ws( 18,  6,  2) =            -0.6565864550849740
  ws( 19,  6,  2) =            -0.6780832145663170
  ws( 20,  6,  2) =            -0.8956548575427170
  ws( 21,  6,  2) =            -0.0431598228997721
  ws( 22,  6,  2) =             0.2448263663448520
  ws( 23,  6,  2) =            -0.1308141470963380
  ws( 24,  6,  2) =             0.2698298326427890
  ws( 25,  6,  2) =             0.0390321776262744
  ws( 26,  6,  2) =             0.7184747994198570
  ws( 27,  6,  2) =            -0.7967671763317620
  ws( 28,  6,  2) =             0.7133012113066550
  ws( 29,  6,  2) =            -0.1164720857209670
  ws( 30,  6,  2) =             0.0748064439991096
  ws( 31,  6,  2) =            -0.0820138050692367
  ws( 32,  6,  2) =            -1.1502998015036301
  ws( 33,  6,  2) =             0.5273714984631850
  ws( 34,  6,  2) =            -0.4622674803552030
  ws( 35,  6,  2) =             0.5303476383332441
  ws( 36,  6,  2) =             0.8520910242275270
  ws( 37,  6,  2) =             0.5563915516110000
  ws( 38,  6,  2) =             0.4432425033968040
  ws( 39,  6,  2) =             0.1065175784489550
  ws( 40,  6,  2) =             0.1943055952526880
  ws( 41,  6,  2) =            -0.2113500858139260
  ws( 42,  6,  2) =            -0.1775946162022470
  ws( 43,  6,  2) =            -1.0720222735006200
  ws( 44,  6,  2) =             0.8268861808067950
  ws( 45,  6,  2) =             0.2992070043839980
  ws( 46,  6,  2) =            -0.2645489133205400
  ws( 47,  6,  2) =            -0.7144123234739830
  ws( 48,  6,  2) =            -0.6168583663439390
  ws( 49,  6,  2) =             0.2528446467349540
  ws( 50,  6,  2) =            -0.1460013634695060
  ws(  1,  7,  2) =             0.2487135085273330
  ws(  2,  7,  2) =             0.1787209017531300
  ws(  3,  7,  2) =            -0.6827858332013780
  ws(  4,  7,  2) =            -0.5957952280718600
  ws(  5,  7,  2) =             0.2963887679251480
  ws(  6,  7,  2) =            -0.5692970259541600
  ws(  7,  7,  2) =             0.3207316373665350
  ws(  8,  7,  2) =            -0.0864907994996193
  ws(  9,  7,  2) =             0.9617464460175990
  ws( 10,  7,  2) =            -0.2091886185479880
  ws( 11,  7,  2) =             0.4772773292834890
  ws( 12,  7,  2) =            -0.7747567357988220
  ws( 13,  7,  2) =             0.0363041378488138
  ws( 14,  7,  2) =            -0.2417045281164630
  ws( 15,  7,  2) =             0.4390250939696930
  ws( 16,  7,  2) =            -0.6429752118032810
  ws( 17,  7,  2) =            -1.0166419097796899
  ws( 18,  7,  2) =             0.6095642445953500
  ws( 19,  7,  2) =             1.0155375506088300
  ws( 20,  7,  2) =             0.2029745229849250
  ws( 21,  7,  2) =             0.4415767118463040
  ws( 22,  7,  2) =             0.2385373873844520
  ws( 23,  7,  2) =             0.5417647451078500
  ws( 24,  7,  2) =             0.3851668241830730
  ws( 25,  7,  2) =            -0.5218067408580500
  ws( 26,  7,  2) =            -0.6801851227775760
  ws( 27,  7,  2) =             1.0118226874231899
  ws( 28,  7,  2) =             0.2337258743572480
  ws( 29,  7,  2) =            -0.3259453807787680
  ws( 30,  7,  2) =             0.7043369032878680
  ws( 31,  7,  2) =            -0.4139217022810660
  ws( 32,  7,  2) =             0.1977326011255060
  ws( 33,  7,  2) =             0.9405845088990740
  ws( 34,  7,  2) =             0.8211346804554880
  ws( 35,  7,  2) =             0.7885639356983190
  ws( 36,  7,  2) =             0.1215538919508060
  ws( 37,  7,  2) =             0.2141048272814950
  ws( 38,  7,  2) =            -0.3835991448398650
  ws( 39,  7,  2) =             0.3673687473631520
  ws( 40,  7,  2) =            -0.8916850701977320
  ws( 41,  7,  2) =             0.0829796582674535
  ws( 42,  7,  2) =             0.5892713695294840
  ws( 43,  7,  2) =            -0.9039166398168040
  ws( 44,  7,  2) =            -0.1719798657257220
  ws( 45,  7,  2) =            -0.1963322006353920
  ws( 46,  7,  2) =            -0.1638354928350530
  ws( 47,  7,  2) =            -0.1429495493976780
  ws( 48,  7,  2) =             0.2482620776355230
  ws( 49,  7,  2) =            -0.5858659960312930
  ws( 50,  7,  2) =            -0.5452265864930690
  ws(  1,  8,  2) =            -0.0249046355352741
  ws(  2,  8,  2) =             0.5070065523827620
  ws(  3,  8,  2) =            -0.3784676796864970
  ws(  4,  8,  2) =             0.8436493575962550
  ws(  5,  8,  2) =            -0.7952629786876990
  ws(  6,  8,  2) =            -0.3225655648990240
  ws(  7,  8,  2) =             0.0739691724084444
  ws(  8,  8,  2) =            -1.0933732131989200
  ws(  9,  8,  2) =             0.6591906910584791
  ws( 10,  8,  2) =             0.4090286684947200
  ws( 11,  8,  2) =            -0.0062722554133676
  ws( 12,  8,  2) =             0.5475636104369130
  ws( 13,  8,  2) =            -0.6724198356771740
  ws( 14,  8,  2) =             0.0335660495554518
  ws( 15,  8,  2) =            -1.1456862096241500
  ws( 16,  8,  2) =             0.7484585481329390
  ws( 17,  8,  2) =            -0.2215239322225320
  ws( 18,  8,  2) =             0.3627533534845880
  ws( 19,  8,  2) =             0.7894224035123740
  ws( 20,  8,  2) =            -0.0607943984453734
  ws( 21,  8,  2) =             0.5908515203100680
  ws( 22,  8,  2) =             0.5326011063265950
  ws( 23,  8,  2) =            -0.0625108241473435
  ws( 24,  8,  2) =            -0.5036167785513310
  ws( 25,  8,  2) =            -0.3607775532174490
  ws( 26,  8,  2) =            -0.9411984407374570
  ws( 27,  8,  2) =            -0.0231739522721767
  ws( 28,  8,  2) =             0.1344029981258170
  ws( 29,  8,  2) =             0.6093075535579699
  ws( 30,  8,  2) =            -0.0679759216131552
  ws( 31,  8,  2) =            -0.4671817409335590
  ws( 32,  8,  2) =             0.5635356901389590
  ws( 33,  8,  2) =             0.7188034879509850
  ws( 34,  8,  2) =            -0.2727817905749390
  ws( 35,  8,  2) =            -0.1089043440247660
  ws( 36,  8,  2) =             0.4463279776225890
  ws( 37,  8,  2) =             0.0341059024086823
  ws( 38,  8,  2) =            -0.5776669554312270
  ws( 39,  8,  2) =             0.6900863832595300
  ws( 40,  8,  2) =             0.7144426447747370
  ws( 41,  8,  2) =             0.9310442853108980
  ws( 42,  8,  2) =            -0.3799230339268760
  ws( 43,  8,  2) =            -0.5990903336901150
  ws( 44,  8,  2) =             0.1443235939085540
  ws( 45,  8,  2) =             0.0851878454270120
  ws( 46,  8,  2) =            -1.0705587123799800
  ws( 47,  8,  2) =             0.6259378925536800
  ws( 48,  8,  2) =            -1.2366427621802001
  ws( 49,  8,  2) =             0.5075007313320010
  ws( 50,  8,  2) =            -0.0957075330400815
  ws(  1,  9,  2) =             0.2732411105968480
  ws(  2,  9,  2) =             0.9127262215000290
  ws(  3,  9,  2) =            -0.9318580502214980
  ws(  4,  9,  2) =            -0.9328289632924680
  ws(  5,  9,  2) =            -0.2968702200820390
  ws(  6,  9,  2) =            -0.0372580834018933
  ws(  7,  9,  2) =             0.5826621417509880
  ws(  8,  9,  2) =             0.1194932984157220
  ws(  9,  9,  2) =             0.6338628653450030
  ws( 10,  9,  2) =             0.9267570172163960
  ws( 11,  9,  2) =             0.8266785870021029
  ws( 12,  9,  2) =            -0.8526126053196120
  ws( 13,  9,  2) =             0.8578480605913950
  ws( 14,  9,  2) =            -0.0147846108833109
  ws( 15,  9,  2) =            -0.0640445116659714
  ws( 16,  9,  2) =             0.4607664284609440
  ws( 17,  9,  2) =             0.6531912977187130
  ws( 18,  9,  2) =             0.6263773344318380
  ws( 19,  9,  2) =             0.9451218803107850
  ws( 20,  9,  2) =            -0.7245882290853400
  ws( 21,  9,  2) =            -0.6323411606869090
  ws( 22,  9,  2) =            -0.4551121942073120
  ws( 23,  9,  2) =             0.6234181181061210
  ws( 24,  9,  2) =             0.5440755073434890
  ws( 25,  9,  2) =             0.5402704417435410
  ws( 26,  9,  2) =            -1.0064535481632799
  ws( 27,  9,  2) =            -0.1358725549855670
  ws( 28,  9,  2) =             0.9671429839542520
  ws( 29,  9,  2) =             0.3444862160405400
  ws( 30,  9,  2) =            -0.5853907850009300
  ws( 31,  9,  2) =             0.7975294557549920
  ws( 32,  9,  2) =             0.5619897245129650
  ws( 33,  9,  2) =             0.8801503295520560
  ws( 34,  9,  2) =            -0.1080077060790670
  ws( 35,  9,  2) =            -0.5788970929388439
  ws( 36,  9,  2) =            -0.2108675031822300
  ws( 37,  9,  2) =             0.0486303953668358
  ws( 38,  9,  2) =             0.0420530694628403
  ws( 39,  9,  2) =            -0.2410143626033560
  ws( 40,  9,  2) =             0.0109986699213332
  ws( 41,  9,  2) =             0.7397582861847430
  ws( 42,  9,  2) =            -1.2619101492895100
  ws( 43,  9,  2) =             0.7692779402845560
  ws( 44,  9,  2) =             0.5896183890355150
  ws( 45,  9,  2) =            -0.1587019298763670
  ws( 46,  9,  2) =             0.6300529562482510
  ws( 47,  9,  2) =             0.1911577430849900
  ws( 48,  9,  2) =            -0.1916741673417690
  ws( 49,  9,  2) =             0.4881175413978870
  ws( 50,  9,  2) =             1.0004809632414500
  ws(  1, 10,  2) =            -0.7066392262960280
  ws(  2, 10,  2) =            -0.3554705425245700
  ws(  3, 10,  2) =            -0.7648106524271900
  ws(  4, 10,  2) =            -0.6570487240588120
  ws(  5, 10,  2) =            -0.7602493226920340
  ws(  6, 10,  2) =            -0.9909042724560290
  ws(  7, 10,  2) =             0.9593800375447260
  ws(  8, 10,  2) =            -0.4202837661331910
  ws(  9, 10,  2) =            -0.7557203930350050
  ws( 10, 10,  2) =             0.0680389892038759
  ws( 11, 10,  2) =            -0.6898959279190330
  ws( 12, 10,  2) =             0.0995757546440668
  ws( 13, 10,  2) =            -0.4630565464031390
  ws( 14, 10,  2) =             0.1604737710259560
  ws( 15, 10,  2) =             0.2572852756541110
  ws( 16, 10,  2) =             0.8035685686504750
  ws( 17, 10,  2) =             0.1834398159903780
  ws( 18, 10,  2) =             0.1734009508349040
  ws( 19, 10,  2) =             0.8113797007777660
  ws( 20, 10,  2) =            -0.1932989564696670
  ws( 21, 10,  2) =            -0.2706734703696360
  ws( 22, 10,  2) =             0.0419393190928456
  ws( 23, 10,  2) =             0.5132723654803700
  ws( 24, 10,  2) =            -0.2666920996335570
  ws( 25, 10,  2) =             0.4488975034154700
  ws( 26, 10,  2) =             0.5839434653555839
  ws( 27, 10,  2) =            -0.2510917490443470
  ws( 28, 10,  2) =             0.9810699258372770
  ws( 29, 10,  2) =            -0.4021960369976700
  ws( 30, 10,  2) =             0.1983409642887640
  ws( 31, 10,  2) =            -0.1011188821453960
  ws( 32, 10,  2) =             0.1876954572215960
  ws( 33, 10,  2) =            -0.8826665581656920
  ws( 34, 10,  2) =            -0.5643464171401290
  ws( 35, 10,  2) =            -0.9536309234130590
  ws( 36, 10,  2) =            -0.2132812272944800
  ws( 37, 10,  2) =            -0.9091067473738280
  ws( 38, 10,  2) =            -0.4175905158480870
  ws( 39, 10,  2) =             0.4669179632549360
  ws( 40, 10,  2) =             0.8413368441230680
  ws( 41, 10,  2) =             0.0672474390775152
  ws( 42, 10,  2) =            -0.2168113475824940
  ws( 43, 10,  2) =             0.5044837916304400
  ws( 44, 10,  2) =             0.7635516692795350
  ws( 45, 10,  2) =            -0.4257858339623020
  ws( 46, 10,  2) =             0.8681467687883800
  ws( 47, 10,  2) =             0.3045746715109280
  ws( 48, 10,  2) =            -0.5600132993284760
  ws( 49, 10,  2) =            -0.3280315192413840
  ws( 50, 10,  2) =             0.1850577015069400
  ws(  1, 11,  2) =            -0.6163675614598439
  ws(  2, 11,  2) =            -0.6895605273095150
  ws(  3, 11,  2) =             0.5015511112531530
  ws(  4, 11,  2) =             0.2299315971238720
  ws(  5, 11,  2) =            -0.7276188300709270
  ws(  6, 11,  2) =             0.4384821370033600
  ws(  7, 11,  2) =            -0.3306146043644300
  ws(  8, 11,  2) =             0.3993371274039390
  ws(  9, 11,  2) =            -0.5752986219088230
  ws( 10, 11,  2) =             0.5236676267326730
  ws( 11, 11,  2) =            -0.5509329824208800
  ws( 12, 11,  2) =             0.5470262100051200
  ws( 13, 11,  2) =            -0.6668528364890750
  ws( 14, 11,  2) =            -0.3723700964224140
  ws( 15, 11,  2) =             0.5118792073817140
  ws( 16, 11,  2) =            -0.2133448589342530
  ws( 17, 11,  2) =            -0.3643105542565110
  ws( 18, 11,  2) =            -0.6654313594509390
  ws( 19, 11,  2) =            -0.1015962080050560
  ws( 20, 11,  2) =             0.9445802381631290
  ws( 21, 11,  2) =             1.4341916896278100
  ws( 22, 11,  2) =             0.3317920624640990
  ws( 23, 11,  2) =             0.0773899208978392
  ws( 24, 11,  2) =            -0.1224895241509250
  ws( 25, 11,  2) =             0.2712630470210250
  ws( 26, 11,  2) =             0.5703151412150100
  ws( 27, 11,  2) =             0.1492683816188430
  ws( 28, 11,  2) =            -0.7048519348348040
  ws( 29, 11,  2) =            -0.0250267408222914
  ws( 30, 11,  2) =             0.2373545885629200
  ws( 31, 11,  2) =             0.8939498615102740
  ws( 32, 11,  2) =             1.4040732899705000
  ws( 33, 11,  2) =            -1.0789300115993401
  ws( 34, 11,  2) =             0.4106759821644970
  ws( 35, 11,  2) =            -0.7039624020224740
  ws( 36, 11,  2) =            -0.5747326411494450
  ws( 37, 11,  2) =             0.8722954423894620
  ws( 38, 11,  2) =             0.6388629546719440
  ws( 39, 11,  2) =             1.0603854678119700
  ws( 40, 11,  2) =             1.3798301533714199
  ws( 41, 11,  2) =             0.4876603377901080
  ws( 42, 11,  2) =            -0.2431317378672890
  ws( 43, 11,  2) =             0.8354806778461270
  ws( 44, 11,  2) =             0.2475850689296230
  ws( 45, 11,  2) =            -0.0197217296032698
  ws( 46, 11,  2) =            -0.3755222084133260
  ws( 47, 11,  2) =             0.5491057959947661
  ws( 48, 11,  2) =            -0.0247599726629216
  ws( 49, 11,  2) =            -0.9699291021261660
  ws( 50, 11,  2) =            -0.8330645601513160
  ws(  1, 12,  2) =             0.6968276452714320
  ws(  2, 12,  2) =             0.4731707958028330
  ws(  3, 12,  2) =             0.0234284306848461
  ws(  4, 12,  2) =            -0.3566348557114230
  ws(  5, 12,  2) =            -0.1692505734240570
  ws(  6, 12,  2) =            -0.1061288637669420
  ws(  7, 12,  2) =             0.8090534971193570
  ws(  8, 12,  2) =            -2.0801995783322198
  ws(  9, 12,  2) =            -0.3315694269141540
  ws( 10, 12,  2) =            -0.5591379673621060
  ws( 11, 12,  2) =            -0.1874559722776310
  ws( 12, 12,  2) =            -0.4307985795718710
  ws( 13, 12,  2) =             0.5715671733529760
  ws( 14, 12,  2) =            -0.2653829610143350
  ws( 15, 12,  2) =            -1.7905053973251599
  ws( 16, 12,  2) =            -0.3209964294732510
  ws( 17, 12,  2) =             0.0727836856544590
  ws( 18, 12,  2) =            -0.0195535290486316
  ws( 19, 12,  2) =             0.5161144164415410
  ws( 20, 12,  2) =            -1.7859147783946101
  ws( 21, 12,  2) =             0.3715838227919050
  ws( 22, 12,  2) =            -0.7963613172405170
  ws( 23, 12,  2) =            -0.7772349113179400
  ws( 24, 12,  2) =             0.4387394199852920
  ws( 25, 12,  2) =             0.0269669955751104
  ws( 26, 12,  2) =            -0.2047450176379000
  ws( 27, 12,  2) =             0.4308738020831290
  ws( 28, 12,  2) =             0.0417439519540075
  ws( 29, 12,  2) =             0.3230711070694780
  ws( 30, 12,  2) =             0.1015205104485770
  ws( 31, 12,  2) =             0.2098538896056790
  ws( 32, 12,  2) =            -0.4445201232181780
  ws( 33, 12,  2) =            -0.2843369266308310
  ws( 34, 12,  2) =             0.2267902172119140
  ws( 35, 12,  2) =            -1.2174578799030000
  ws( 36, 12,  2) =            -0.1155432273876000
  ws( 37, 12,  2) =             0.6313610135121021
  ws( 38, 12,  2) =            -0.1513316515723830
  ws( 39, 12,  2) =             1.0429529413837200
  ws( 40, 12,  2) =            -1.2886472485466800
  ws( 41, 12,  2) =            -0.8489700458908200
  ws( 42, 12,  2) =             0.8831208027089110
  ws( 43, 12,  2) =            -1.3065788063305499
  ws( 44, 12,  2) =            -0.8466896613593090
  ws( 45, 12,  2) =             1.0006497413907200
  ws( 46, 12,  2) =             0.6385606962970790
  ws( 47, 12,  2) =            -0.1870221734665230
  ws( 48, 12,  2) =             0.6157325941152690
  ws( 49, 12,  2) =            -0.2497952947873410
  ws( 50, 12,  2) =            -0.1620061437924440
  ws(  1, 13,  2) =             0.5085102510276880
  ws(  2, 13,  2) =             0.2616918898772420
  ws(  3, 13,  2) =             0.3284960367197340
  ws(  4, 13,  2) =            -0.2293436303514610
  ws(  5, 13,  2) =            -0.1234924648079060
  ws(  6, 13,  2) =            -0.3279669422346640
  ws(  7, 13,  2) =            -0.7671517334231220
  ws(  8, 13,  2) =            -0.7071898843258320
  ws(  9, 13,  2) =            -0.6598477248538490
  ws( 10, 13,  2) =             1.2555634273342700
  ws( 11, 13,  2) =            -0.0600839375563560
  ws( 12, 13,  2) =            -0.7785448728249670
  ws( 13, 13,  2) =             0.5366068396113000
  ws( 14, 13,  2) =             0.4800043688426400
  ws( 15, 13,  2) =            -1.3578543787140400
  ws( 16, 13,  2) =            -1.1120357950787401
  ws( 17, 13,  2) =            -0.3050790859687670
  ws( 18, 13,  2) =             0.8817337391572240
  ws( 19, 13,  2) =             0.3365157720446410
  ws( 20, 13,  2) =             0.3707142520335590
  ws( 21, 13,  2) =            -0.7147473109715150
  ws( 22, 13,  2) =             0.3976496146737990
  ws( 23, 13,  2) =            -0.6611159979878500
  ws( 24, 13,  2) =             0.8122537370222840
  ws( 25, 13,  2) =             0.2240320009936650
  ws( 26, 13,  2) =            -0.6664707468227830
  ws( 27, 13,  2) =             1.6943972506411100
  ws( 28, 13,  2) =            -0.5838479038501710
  ws( 29, 13,  2) =            -0.1125567173986100
  ws( 30, 13,  2) =            -0.7797164891334900
  ws( 31, 13,  2) =             0.7822743825532910
  ws( 32, 13,  2) =             0.7168567442319500
  ws( 33, 13,  2) =            -0.4058041707017940
  ws( 34, 13,  2) =             0.9137021716864480
  ws( 35, 13,  2) =            -0.4661345275369740
  ws( 36, 13,  2) =             1.0798498728811801
  ws( 37, 13,  2) =            -0.7207898537054230
  ws( 38, 13,  2) =             0.8169018976619840
  ws( 39, 13,  2) =             0.8279156265200480
  ws( 40, 13,  2) =            -0.3692913086675820
  ws( 41, 13,  2) =            -1.0551876102675199
  ws( 42, 13,  2) =            -0.3644401216121060
  ws( 43, 13,  2) =            -0.4585342345592340
  ws( 44, 13,  2) =            -0.4327694270160220
  ws( 45, 13,  2) =             0.0379828319762984
  ws( 46, 13,  2) =            -0.4644078977259980
  ws( 47, 13,  2) =             0.5053288325828800
  ws( 48, 13,  2) =             0.2011522092845250
  ws( 49, 13,  2) =            -0.5921637791686950
  ws( 50, 13,  2) =             0.6485143975967260
  ws(  1, 14,  2) =            -0.5301125430236120
  ws(  2, 14,  2) =             0.6152702365155260
  ws(  3, 14,  2) =             0.4268594473065760
  ws(  4, 14,  2) =            -0.6827688872704090
  ws(  5, 14,  2) =             0.0354058340799587
  ws(  6, 14,  2) =             0.8081328037184810
  ws(  7, 14,  2) =            -0.1589714195019170
  ws(  8, 14,  2) =             2.2759198168329902
  ws(  9, 14,  2) =             0.1369335605414270
  ws( 10, 14,  2) =            -0.4073326303893240
  ws( 11, 14,  2) =             0.7136252323779950
  ws( 12, 14,  2) =             0.1179366694172510
  ws( 13, 14,  2) =            -0.1310276406265090
  ws( 14, 14,  2) =            -1.3337562467005200
  ws( 15, 14,  2) =             0.5680400981009300
  ws( 16, 14,  2) =             0.2560675087829210
  ws( 17, 14,  2) =             0.7426741036664291
  ws( 18, 14,  2) =            -0.9426200045991960
  ws( 19, 14,  2) =            -0.1221989700674300
  ws( 20, 14,  2) =             0.7345290328806400
  ws( 21, 14,  2) =            -0.3590658082876650
  ws( 22, 14,  2) =             1.2202546378044801
  ws( 23, 14,  2) =             0.4742197866540170
  ws( 24, 14,  2) =             1.3199929788122899
  ws( 25, 14,  2) =             0.5385333169381010
  ws( 26, 14,  2) =             0.7681215040713000
  ws( 27, 14,  2) =             0.1606615059786380
  ws( 28, 14,  2) =            -0.9605763997132930
  ws( 29, 14,  2) =            -1.2445337330870201
  ws( 30, 14,  2) =             1.1229292295415101
  ws( 31, 14,  2) =             0.7533897154633230
  ws( 32, 14,  2) =             0.6674904900706630
  ws( 33, 14,  2) =            -1.5547063094129401
  ws( 34, 14,  2) =            -0.1471210138078300
  ws( 35, 14,  2) =            -0.1319854537562820
  ws( 36, 14,  2) =            -0.5363908431893750
  ws( 37, 14,  2) =             0.7525937669700991
  ws( 38, 14,  2) =             0.8156402605028640
  ws( 39, 14,  2) =             0.5166277594780579
  ws( 40, 14,  2) =             1.8169331037860701
  ws( 41, 14,  2) =             0.9754140724036940
  ws( 42, 14,  2) =            -1.0593044944992700
  ws( 43, 14,  2) =             1.2204276089448201
  ws( 44, 14,  2) =            -0.6564182766999900
  ws( 45, 14,  2) =             1.0667424165617601
  ws( 46, 14,  2) =            -0.6606984495828860
  ws( 47, 14,  2) =             0.1250746479023290
  ws( 48, 14,  2) =             1.0296773907243399
  ws( 49, 14,  2) =            -0.3970390481546590
  ws( 50, 14,  2) =             0.6840755133825440
  ws(  1, 15,  2) =            -0.7308306086871650
  ws(  2, 15,  2) =            -0.6140296055522680
  ws(  3, 15,  2) =             0.7317074736505030
  ws(  4, 15,  2) =             0.7134439724106150
  ws(  5, 15,  2) =             0.7380877189740790
  ws(  6, 15,  2) =            -0.8018802280459770
  ws(  7, 15,  2) =            -0.1423082280083000
  ws(  8, 15,  2) =            -1.1497405469621900
  ws(  9, 15,  2) =            -0.0028926207676620
  ws( 10, 15,  2) =            -0.8545172747334960
  ws( 11, 15,  2) =             1.1348332227384701
  ws( 12, 15,  2) =             1.0345463661077301
  ws( 13, 15,  2) =             0.3808133442224240
  ws( 14, 15,  2) =            -0.3971456857156950
  ws( 15, 15,  2) =             0.3980912116395810
  ws( 16, 15,  2) =            -1.1206612998767700
  ws( 17, 15,  2) =             0.2810152247729520
  ws( 18, 15,  2) =             0.1313970700991220
  ws( 19, 15,  2) =            -0.7008879038868620
  ws( 20, 15,  2) =             0.5661743120107809
  ws( 21, 15,  2) =             1.5688844357692500
  ws( 22, 15,  2) =             1.3488750225424799
  ws( 23, 15,  2) =             0.8227763920498140
  ws( 24, 15,  2) =             0.3824330914023990
  ws( 25, 15,  2) =             0.2939039553520710
  ws( 26, 15,  2) =             0.3851652067789810
  ws( 27, 15,  2) =             1.4845103153939501
  ws( 28, 15,  2) =             0.0777230895958694
  ws( 29, 15,  2) =             0.5121901391236821
  ws( 30, 15,  2) =            -0.9208031831676730
  ws( 31, 15,  2) =            -0.4939834463238690
  ws( 32, 15,  2) =             2.1686992578614102
  ws( 33, 15,  2) =            -0.9610915081220019
  ws( 34, 15,  2) =            -0.8300054549739880
  ws( 35, 15,  2) =            -0.1289958183810710
  ws( 36, 15,  2) =            -0.0793328147257861
  ws( 37, 15,  2) =            -0.6012793601411029
  ws( 38, 15,  2) =            -0.3956698949440160
  ws( 39, 15,  2) =            -0.9901654162616860
  ws( 40, 15,  2) =             1.8146748513309201
  ws( 41, 15,  2) =            -0.9521919462673810
  ws( 42, 15,  2) =            -0.1423591044775930
  ws( 43, 15,  2) =             0.1140557122440390
  ws( 44, 15,  2) =            -0.6036325191187361
  ws( 45, 15,  2) =            -1.0958077677103000
  ws( 46, 15,  2) =             0.5083640821930270
  ws( 47, 15,  2) =             0.1309405631063070
  ws( 48, 15,  2) =            -1.7253372482181100
  ws( 49, 15,  2) =            -0.3431941586147090
  ws( 50, 15,  2) =             0.4720743373575340
  ws(  1, 16,  2) =             0.3424023622022810
  ws(  2, 16,  2) =             0.9756153751825780
  ws(  3, 16,  2) =            -0.8090364010064860
  ws(  4, 16,  2) =            -0.9347240792922320
  ws(  5, 16,  2) =             0.5583572203502850
  ws(  6, 16,  2) =            -0.1409965639487630
  ws(  7, 16,  2) =            -0.3310153563759110
  ws(  8, 16,  2) =            -4.4581364609460099
  ws(  9, 16,  2) =             0.0218251478254529
  ws( 10, 16,  2) =             0.4821912968216950
  ws( 11, 16,  2) =            -1.2079336678010999
  ws( 12, 16,  2) =            -0.7246926396404400
  ws( 13, 16,  2) =             0.5189145003055760
  ws( 14, 16,  2) =             0.5970482842566950
  ws( 15, 16,  2) =            -1.1063801326168801
  ws( 16, 16,  2) =             0.3070578724140920
  ws( 17, 16,  2) =             0.2647938966585810
  ws( 18, 16,  2) =             0.6013798008807640
  ws( 19, 16,  2) =             0.1132531532306540
  ws( 20, 16,  2) =            -2.4448466266446900
  ws( 21, 16,  2) =            -0.8404448234323600
  ws( 22, 16,  2) =            -1.7218139631847500
  ws( 23, 16,  2) =             0.4568468986708880
  ws( 24, 16,  2) =             0.1756795156126710
  ws( 25, 16,  2) =            -1.0293282969839701
  ws( 26, 16,  2) =            -1.0102700221214700
  ws( 27, 16,  2) =             0.0091592538624118
  ws( 28, 16,  2) =             0.7887080793962800
  ws( 29, 16,  2) =             1.2760435131057799
  ws( 30, 16,  2) =            -0.6789257853823940
  ws( 31, 16,  2) =             0.2519631074232670
  ws( 32, 16,  2) =            -0.9430818279553770
  ws( 33, 16,  2) =             0.4614529271454970
  ws( 34, 16,  2) =             0.6471599405293040
  ws( 35, 16,  2) =            -1.8695987550214299
  ws( 36, 16,  2) =             0.7871006234350409
  ws( 37, 16,  2) =             0.3514442714793220
  ws( 38, 16,  2) =            -0.2875817087337200
  ws( 39, 16,  2) =             0.2174167404186820
  ws( 40, 16,  2) =            -1.2154317589992101
  ws( 41, 16,  2) =            -0.0682087426440380
  ws( 42, 16,  2) =            -0.3500278050074580
  ws( 43, 16,  2) =            -0.4806807908042150
  ws( 44, 16,  2) =            -0.3378885690661110
  ws( 45, 16,  2) =             0.5649423197570080
  ws( 46, 16,  2) =             0.3422863361491260
  ws( 47, 16,  2) =             0.2935409151136440
  ws( 48, 16,  2) =             0.6294888525785290
  ws( 49, 16,  2) =            -0.1714028327789330
  ws( 50, 16,  2) =             0.5425400362053040
  ws(  1, 17,  2) =            -0.2990531148082120
  ws(  2, 17,  2) =            -0.0460238879613520
  ws(  3, 17,  2) =            -0.2762224099659460
  ws(  4, 17,  2) =             0.3868544421627860
  ws(  5, 17,  2) =             0.5543338922964320
  ws(  6, 17,  2) =             0.8587347299102630
  ws(  7, 17,  2) =             0.3365317538797040
  ws(  8, 17,  2) =            -0.8565200498466770
  ws(  9, 17,  2) =            -0.7685260436225000
  ws( 10, 17,  2) =             0.4014382634593990
  ws( 11, 17,  2) =            -1.3404306744033700
  ws( 12, 17,  2) =             0.6448235357741140
  ws( 13, 17,  2) =             0.1369276754955210
  ws( 14, 17,  2) =             0.6193726400629150
  ws( 15, 17,  2) =            -1.0083811147860899
  ws( 16, 17,  2) =             0.6518242097170610
  ws( 17, 17,  2) =             0.4868386561480540
  ws( 18, 17,  2) =             0.0796275809934675
  ws( 19, 17,  2) =             0.0478822892100384
  ws( 20, 17,  2) =            -3.4538629517750001
  ws( 21, 17,  2) =             0.3373269669007510
  ws( 22, 17,  2) =            -0.8501641481256860
  ws( 23, 17,  2) =             0.6666199944385490
  ws( 24, 17,  2) =            -0.0745828899528064
  ws( 25, 17,  2) =             0.5051289002224890
  ws( 26, 17,  2) =             0.7847051275628900
  ws( 27, 17,  2) =             1.2430077641316200
  ws( 28, 17,  2) =            -0.6316159174044590
  ws( 29, 17,  2) =            -0.4335775950256450
  ws( 30, 17,  2) =             0.0697088626218682
  ws( 31, 17,  2) =             0.2103002333397770
  ws( 32, 17,  2) =            -0.4609748330053980
  ws( 33, 17,  2) =            -0.4008118276074430
  ws( 34, 17,  2) =            -0.4294805289929720
  ws( 35, 17,  2) =            -0.2750901256524760
  ws( 36, 17,  2) =             0.7770203636004940
  ws( 37, 17,  2) =            -0.0658023799625824
  ws( 38, 17,  2) =            -0.4366698725682870
  ws( 39, 17,  2) =            -0.2647464653893840
  ws( 40, 17,  2) =            -1.5087812433265899
  ws( 41, 17,  2) =             0.0631040600575548
  ws( 42, 17,  2) =            -0.1601774158331940
  ws( 43, 17,  2) =            -1.6155794556948200
  ws( 44, 17,  2) =            -0.0535018368224941
  ws( 45, 17,  2) =             0.9005271503774410
  ws( 46, 17,  2) =            -0.7007564204081810
  ws( 47, 17,  2) =            -0.3394524933540900
  ws( 48, 17,  2) =             0.2803305840037680
  ws( 49, 17,  2) =            -0.9004698103169150
  ws( 50, 17,  2) =            -0.2616665084859250
  ws(  1, 18,  2) =            -0.4548806340595260
  ws(  2, 18,  2) =            -0.8579979740944410
  ws(  3, 18,  2) =            -0.8576589328491290
  ws(  4, 18,  2) =             0.5309334954501620
  ws(  5, 18,  2) =             0.8119186240884130
  ws(  6, 18,  2) =             0.6778803005090120
  ws(  7, 18,  2) =            -0.0427111636946690
  ws(  8, 18,  2) =            -0.5626806081476000
  ws(  9, 18,  2) =            -0.1718905027360920
  ws( 10, 18,  2) =             0.7717612639136300
  ws( 11, 18,  2) =             0.5110879439451500
  ws( 12, 18,  2) =             0.1927199208548440
  ws( 13, 18,  2) =            -0.2194179951225670
  ws( 14, 18,  2) =            -0.9693420673509040
  ws( 15, 18,  2) =             0.9006040232037990
  ws( 16, 18,  2) =             0.3255005609813610
  ws( 17, 18,  2) =            -1.0443381186537000
  ws( 18, 18,  2) =             0.9166339109468030
  ws( 19, 18,  2) =            -0.8492571229211520
  ws( 20, 18,  2) =             3.9009944190118402
  ws( 21, 18,  2) =             2.4144480564612900
  ws( 22, 18,  2) =             1.4312788850559000
  ws( 23, 18,  2) =            -0.1431029891314460
  ws( 24, 18,  2) =             0.1378823258118220
  ws( 25, 18,  2) =             1.3173954414119800
  ws( 26, 18,  2) =            -0.6759377026106600
  ws( 27, 18,  2) =             2.8407411665453801
  ws( 28, 18,  2) =            -0.2934574535985950
  ws( 29, 18,  2) =            -0.3395303186522120
  ws( 30, 18,  2) =            -1.9005868603621801
  ws( 31, 18,  2) =             0.5533481032737499
  ws( 32, 18,  2) =             1.7125799470506800
  ws( 33, 18,  2) =            -0.5026934493183790
  ws( 34, 18,  2) =             0.9093093684912320
  ws( 35, 18,  2) =             0.6039658080279010
  ws( 36, 18,  2) =             0.5267916128119829
  ws( 37, 18,  2) =            -0.1985166800806180
  ws( 38, 18,  2) =             0.3039030887652080
  ws( 39, 18,  2) =            -0.1184761477347320
  ws( 40, 18,  2) =             1.8932706440718601
  ws( 41, 18,  2) =             0.4649657895418500
  ws( 42, 18,  2) =             1.0089364939271801
  ws( 43, 18,  2) =             1.2192180554638801
  ws( 44, 18,  2) =             0.8933207709457091
  ws( 45, 18,  2) =            -0.8651942114863310
  ws( 46, 18,  2) =             0.3126839436037280
  ws( 47, 18,  2) =            -0.9922080371102510
  ws( 48, 18,  2) =            -2.0208527113299701
  ws( 49, 18,  2) =            -0.9002102696875460
  ws( 50, 18,  2) =             0.1246114023000200
  ws(  1, 19,  2) =            -0.5159564438131440
  ws(  2, 19,  2) =            -0.6568006500840210
  ws(  3, 19,  2) =            -0.0972008135270142
  ws(  4, 19,  2) =            -0.2096100929657760
  ws(  5, 19,  2) =             0.7507192095488460
  ws(  6, 19,  2) =             0.1509811530276670
  ws(  7, 19,  2) =             0.9216183510040979
  ws(  8, 19,  2) =            -1.5473452238801599
  ws(  9, 19,  2) =             0.6015752110459150
  ws( 10, 19,  2) =             0.2052170551656910
  ws( 11, 19,  2) =            -0.8235799715860170
  ws( 12, 19,  2) =             0.2621478756334050
  ws( 13, 19,  2) =             1.1211791231590100
  ws( 14, 19,  2) =             0.8805567337814890
  ws( 15, 19,  2) =            -1.6797607190438399
  ws( 16, 19,  2) =             0.4108831063342760
  ws( 17, 19,  2) =             0.1827142492958590
  ws( 18, 19,  2) =             0.9473343547965780
  ws( 19, 19,  2) =             0.4960411801118580
  ws( 20, 19,  2) =            -0.9488397135955570
  ws( 21, 19,  2) =             0.7560475464270480
  ws( 22, 19,  2) =             0.4249781403818890
  ws( 23, 19,  2) =            -0.7191689399764100
  ws( 24, 19,  2) =            -0.3504478955132690
  ws( 25, 19,  2) =            -0.6404675586991100
  ws( 26, 19,  2) =            -0.2793529440322900
  ws( 27, 19,  2) =            -0.1720951563912560
  ws( 28, 19,  2) =             0.9797861530561560
  ws( 29, 19,  2) =            -0.8616037238050400
  ws( 30, 19,  2) =             0.0185526909348291
  ws( 31, 19,  2) =             0.1567349091433210
  ws( 32, 19,  2) =             0.8651745970815730
  ws( 33, 19,  2) =             0.2926944818187630
  ws( 34, 19,  2) =            -0.5173863340675050
  ws( 35, 19,  2) =            -0.2787509050232660
  ws( 36, 19,  2) =            -0.0214743126535955
  ws( 37, 19,  2) =             0.0664787991386789
  ws( 38, 19,  2) =            -0.0783046351454362
  ws( 39, 19,  2) =             0.8407331135468150
  ws( 40, 19,  2) =             0.0400282459683737
  ws( 41, 19,  2) =            -0.2344268698150520
  ws( 42, 19,  2) =             0.7057837684882790
  ws( 43, 19,  2) =             1.0600137796498701
  ws( 44, 19,  2) =             0.6053620071315110
  ws( 45, 19,  2) =            -0.8703614727716060
  ws( 46, 19,  2) =            -0.6848917903004250
  ws( 47, 19,  2) =             0.4937842302618560
  ws( 48, 19,  2) =            -0.3654216727293540
  ws( 49, 19,  2) =             0.7477439365346070
  ws( 50, 19,  2) =             0.5384829962436560
  ws(  1, 20,  2) =             0.0898346606559884
  ws(  2, 20,  2) =             0.7650939068834230
  ws(  3, 20,  2) =            -0.0211740860030287
  ws(  4, 20,  2) =            -0.0298331323977128
  ws(  5, 20,  2) =             0.4647901151710310
  ws(  6, 20,  2) =             0.0600906883611013
  ws(  7, 20,  2) =            -0.9987265856228570
  ws(  8, 20,  2) =             0.2458432546252110
  ws(  9, 20,  2) =             0.6405967350018580
  ws( 10, 20,  2) =            -0.3479083984338190
  ws( 11, 20,  2) =             0.0588412410512025
  ws( 12, 20,  2) =            -0.5876122775869900
  ws( 13, 20,  2) =            -0.8789505664691070
  ws( 14, 20,  2) =             1.0780236385795801
  ws( 15, 20,  2) =            -0.5505467879222070
  ws( 16, 20,  2) =             0.2117777005693050
  ws( 17, 20,  2) =            -0.8523180011605000
  ws( 18, 20,  2) =            -0.4881859379324200
  ws( 19, 20,  2) =            -0.1409965716951490
  ws( 20, 20,  2) =            -1.3451781950480499
  ws( 21, 20,  2) =            -1.1582516121970701
  ws( 22, 20,  2) =            -0.0855061279841325
  ws( 23, 20,  2) =            -0.8540804265569349
  ws( 24, 20,  2) =             0.3005894665526740
  ws( 25, 20,  2) =            -1.1354917739530499
  ws( 26, 20,  2) =            -0.8312443574503240
  ws( 27, 20,  2) =            -1.5417854859428199
  ws( 28, 20,  2) =            -0.9980654278721039
  ws( 29, 20,  2) =             0.4692414522809710
  ws( 30, 20,  2) =             0.6165839487431920
  ws( 31, 20,  2) =            -0.2367385781767150
  ws( 32, 20,  2) =            -1.7432147903206801
  ws( 33, 20,  2) =            -0.4321798616609320
  ws( 34, 20,  2) =            -0.8221540348761950
  ws( 35, 20,  2) =             0.3680293317782290
  ws( 36, 20,  2) =            -0.1846107644373170
  ws( 37, 20,  2) =            -0.6335000295225300
  ws( 38, 20,  2) =             0.6468244504261610
  ws( 39, 20,  2) =            -0.1407433979969390
  ws( 40, 20,  2) =            -0.9937217794985460
  ws( 41, 20,  2) =             0.0567536943670155
  ws( 42, 20,  2) =             0.4246297918391260
  ws( 43, 20,  2) =             0.1707186318002680
  ws( 44, 20,  2) =             0.7694449930131620
  ws( 45, 20,  2) =            -0.2173450095212040
  ws( 46, 20,  2) =             0.6571811935260240
  ws( 47, 20,  2) =             0.9931302080969890
  ws( 48, 20,  2) =             0.9690365968643790
  ws( 49, 20,  2) =            -0.8943458939297561
  ws( 50, 20,  2) =             0.0521027525626481
  ws(  1, 21,  2) =            -0.7765332172600991
  ws(  2, 21,  2) =            -0.8640605864344409
  ws(  3, 21,  2) =             0.5938715468422590
  ws(  4, 21,  2) =            -0.1037819646454670
  ws(  5, 21,  2) =             0.7599191875055510
  ws(  6, 21,  2) =             0.0079048159976510
  ws(  7, 21,  2) =            -0.1970747039563400
  ws(  8, 21,  2) =            -1.7016253747464400
  ws(  9, 21,  2) =            -0.7406064766116250
  ws( 10, 21,  2) =            -0.2295569460950880
  ws( 11, 21,  2) =            -1.3089892300379899
  ws( 12, 21,  2) =            -0.7309560555715690
  ws( 13, 21,  2) =             0.5785385735236310
  ws( 14, 21,  2) =             0.7358154988422100
  ws( 15, 21,  2) =            -2.0754346553490000
  ws( 16, 21,  2) =             0.1212248004412180
  ws( 17, 21,  2) =            -0.7212465922724260
  ws( 18, 21,  2) =            -0.9341016412441880
  ws( 19, 21,  2) =            -0.5851187698338430
  ws( 20, 21,  2) =             0.4917997747735530
  ws( 21, 21,  2) =             0.6388801615363630
  ws( 22, 21,  2) =            -0.0577854578094954
  ws( 23, 21,  2) =             0.4819108024011050
  ws( 24, 21,  2) =            -0.4593920185280400
  ws( 25, 21,  2) =            -0.3349814896774760
  ws( 26, 21,  2) =             0.3827542827332150
  ws( 27, 21,  2) =             2.1074023800598600
  ws( 28, 21,  2) =            -0.3659696010118750
  ws( 29, 21,  2) =             1.0101180462346999
  ws( 30, 21,  2) =            -1.0609486585505501
  ws( 31, 21,  2) =             0.0549445230662431
  ws( 32, 21,  2) =             1.5491390869398500
  ws( 33, 21,  2) =             1.3046867991201001
  ws( 34, 21,  2) =             0.6923393390640790
  ws( 35, 21,  2) =            -0.8466540381091980
  ws( 36, 21,  2) =            -0.8354646641423130
  ws( 37, 21,  2) =             0.1965189679592530
  ws( 38, 21,  2) =            -0.2962443744777180
  ws( 39, 21,  2) =             0.6504517977190720
  ws( 40, 21,  2) =             0.1770597416366100
  ws( 41, 21,  2) =            -0.0094288309989960
  ws( 42, 21,  2) =             0.3832753857366950
  ws( 43, 21,  2) =            -0.1100020334511810
  ws( 44, 21,  2) =             0.7412613747627480
  ws( 45, 21,  2) =            -0.8147040789748839
  ws( 46, 21,  2) =             0.5098870279258650
  ws( 47, 21,  2) =             0.1010557803760250
  ws( 48, 21,  2) =            -0.2541147469440930
  ws( 49, 21,  2) =            -0.1254348543092150
  ws( 50, 21,  2) =            -0.2198282199436030
  ws(  1, 22,  2) =             0.0459103897571225
  ws(  2, 22,  2) =            -0.8208732560513810
  ws(  3, 22,  2) =             0.5112355969454220
  ws(  4, 22,  2) =            -0.4916605097812980
  ws(  5, 22,  2) =            -0.7185907914931650
  ws(  6, 22,  2) =             0.2045069191443790
  ws(  7, 22,  2) =             0.6279246803086020
  ws(  8, 22,  2) =             1.9357844700826501
  ws(  9, 22,  2) =             0.3041356407341110
  ws( 10, 22,  2) =            -1.5884154410806000
  ws( 11, 22,  2) =            -0.6045593118090840
  ws( 12, 22,  2) =             0.7415271055639170
  ws( 13, 22,  2) =             0.8141443349642350
  ws( 14, 22,  2) =             0.4048827320786610
  ws( 15, 22,  2) =             2.3095087924515898
  ws( 16, 22,  2) =             0.0282181932731967
  ws( 17, 22,  2) =            -1.0112993202657801
  ws( 18, 22,  2) =             0.4571948413333100
  ws( 19, 22,  2) =            -1.5440173525370700
  ws( 20, 22,  2) =             3.2516271988771699
  ws( 21, 22,  2) =            -0.4478094768319060
  ws( 22, 22,  2) =             2.1941804639547802
  ws( 23, 22,  2) =            -0.0071921784541276
  ws( 24, 22,  2) =             0.4453796368958000
  ws( 25, 22,  2) =             0.3285767781963080
  ws( 26, 22,  2) =             0.0263909261736185
  ws( 27, 22,  2) =            -1.0634852663619601
  ws( 28, 22,  2) =             0.6605944274741100
  ws( 29, 22,  2) =            -0.8990326165162970
  ws( 30, 22,  2) =             0.7140252847342510
  ws( 31, 22,  2) =            -0.0468533479353731
  ws( 32, 22,  2) =            -0.6477358906351000
  ws( 33, 22,  2) =            -1.2822601223836001
  ws( 34, 22,  2) =            -0.2480525953600420
  ws( 35, 22,  2) =             0.7980860524418690
  ws( 36, 22,  2) =            -0.7867487797382560
  ws( 37, 22,  2) =             0.6527707024082290
  ws( 38, 22,  2) =            -0.3438936722492620
  ws( 39, 22,  2) =             0.1032077823928800
  ws( 40, 22,  2) =             2.5850194222069400
  ws( 41, 22,  2) =            -0.5871696280402180
  ws( 42, 22,  2) =             0.3308556112095220
  ws( 43, 22,  2) =             0.4609306833637420
  ws( 44, 22,  2) =            -1.0985121205458099
  ws( 45, 22,  2) =            -0.0723779389858791
  ws( 46, 22,  2) =            -0.1868639187311010
  ws( 47, 22,  2) =            -0.7805149718116720
  ws( 48, 22,  2) =             0.0961116076070863
  ws( 49, 22,  2) =             1.0087207741386599
  ws( 50, 22,  2) =             0.1180213123159860
  ws(  1, 23,  2) =            -0.6130231674794860
  ws(  2, 23,  2) =            -0.3061388079143620
  ws(  3, 23,  2) =            -0.5508033253659010
  ws(  4, 23,  2) =            -0.1891940550536810
  ws(  5, 23,  2) =            -0.1898433044634210
  ws(  6, 23,  2) =            -0.7354217254412660
  ws(  7, 23,  2) =             0.0125917363745513
  ws(  8, 23,  2) =            -1.0028254268228300
  ws(  9, 23,  2) =            -0.5818178132206160
  ws( 10, 23,  2) =             0.2559896836099320
  ws( 11, 23,  2) =             0.6641489156107510
  ws( 12, 23,  2) =            -0.4791271113725620
  ws( 13, 23,  2) =             0.2487380613620400
  ws( 14, 23,  2) =            -0.7823149015652920
  ws( 15, 23,  2) =            -0.5124177683674720
  ws( 16, 23,  2) =             0.5368893600790460
  ws( 17, 23,  2) =            -0.1679396585691320
  ws( 18, 23,  2) =            -0.3507190558539430
  ws( 19, 23,  2) =            -0.0734926561243226
  ws( 20, 23,  2) =             1.3820144876510201
  ws( 21, 23,  2) =             1.3163991026928601
  ws( 22, 23,  2) =            -0.2347805423190670
  ws( 23, 23,  2) =             0.6952819485577511
  ws( 24, 23,  2) =            -0.1282321088377330
  ws( 25, 23,  2) =             1.1810616181554601
  ws( 26, 23,  2) =             0.0543916355423005
  ws( 27, 23,  2) =             1.9530329548945899
  ws( 28, 23,  2) =             0.9138131894464880
  ws( 29, 23,  2) =            -0.3622056710373860
  ws( 30, 23,  2) =            -1.2869400218662601
  ws( 31, 23,  2) =            -0.5018622268001990
  ws( 32, 23,  2) =             2.1563432648610301
  ws( 33, 23,  2) =            -0.0590564148755955
  ws( 34, 23,  2) =            -0.5202167414503360
  ws( 35, 23,  2) =             0.7876542828008670
  ws( 36, 23,  2) =            -0.8184108996721720
  ws( 37, 23,  2) =             0.6109201914718549
  ws( 38, 23,  2) =             0.6715098964108320
  ws( 39, 23,  2) =            -0.3308883332433810
  ws( 40, 23,  2) =             1.3096622292526301
  ws( 41, 23,  2) =            -1.0721638118081400
  ws( 42, 23,  2) =            -0.0367245206691043
  ws( 43, 23,  2) =             0.4816560607709050
  ws( 44, 23,  2) =             1.0163868912714999
  ws( 45, 23,  2) =            -0.4433201335081180
  ws( 46, 23,  2) =             0.5806094905787640
  ws( 47, 23,  2) =             0.7927189679039850
  ws( 48, 23,  2) =            -1.2756347018021801
  ws( 49, 23,  2) =            -0.3454634331782040
  ws( 50, 23,  2) =             0.6035116746673330
  ws(  1, 24,  2) =            -0.1840785343401970
  ws(  2, 24,  2) =            -0.9744052203538250
  ws(  3, 24,  2) =             0.2020265190822470
  ws(  4, 24,  2) =             0.3645489118488760
  ws(  5, 24,  2) =            -0.8035062629202820
  ws(  6, 24,  2) =             0.7243937226901230
  ws(  7, 24,  2) =            -0.1410441259159490
  ws(  8, 24,  2) =            -0.1721605502331420
  ws(  9, 24,  2) =            -0.7731545944920040
  ws( 10, 24,  2) =             0.0420444492446796
  ws( 11, 24,  2) =            -0.9366430576443040
  ws( 12, 24,  2) =            -0.1021626546720210
  ws( 13, 24,  2) =             0.2243517470261670
  ws( 14, 24,  2) =            -0.4153328557204580
  ws( 15, 24,  2) =            -1.2811387807651700
  ws( 16, 24,  2) =             0.8691065241743809
  ws( 17, 24,  2) =             0.4393888827707280
  ws( 18, 24,  2) =             0.8480859612945399
  ws( 19, 24,  2) =            -1.0042551529093700
  ws( 20, 24,  2) =             1.0612069657577901
  ws( 21, 24,  2) =             0.9054319799611790
  ws( 22, 24,  2) =             0.5617456155811390
  ws( 23, 24,  2) =            -0.5372875873844410
  ws( 24, 24,  2) =            -0.6550787488372500
  ws( 25, 24,  2) =             0.9571715710897770
  ws( 26, 24,  2) =             0.5246291452568850
  ws( 27, 24,  2) =             1.4530701667045800
  ws( 28, 24,  2) =            -0.4076780983015890
  ws( 29, 24,  2) =             0.8503534416812200
  ws( 30, 24,  2) =            -0.5415414156412510
  ws( 31, 24,  2) =             0.2569232535301750
  ws( 32, 24,  2) =             0.0655319292175263
  ws( 33, 24,  2) =             0.6795826136676040
  ws( 34, 24,  2) =            -0.3146298383611030
  ws( 35, 24,  2) =            -0.8647586287244360
  ws( 36, 24,  2) =             0.6396210812564490
  ws( 37, 24,  2) =            -0.1593923719766090
  ws( 38, 24,  2) =             0.0796991256014871
  ws( 39, 24,  2) =             0.4848447157135850
  ws( 40, 24,  2) =             0.7458296018077560
  ws( 41, 24,  2) =            -0.9002105673550860
  ws( 42, 24,  2) =             0.3292431524873690
  ws( 43, 24,  2) =             1.0430826876165600
  ws( 44, 24,  2) =             0.7059234532558710
  ws( 45, 24,  2) =             0.7528871936790970
  ws( 46, 24,  2) =            -0.5480309774021090
  ws( 47, 24,  2) =            -0.3805940014042650
  ws( 48, 24,  2) =             0.1372871315633580
  ws( 49, 24,  2) =            -0.4056982164131060
  ws( 50, 24,  2) =             0.6955968964135710
  ws(  1, 25,  2) =            -0.0691685499100305
  ws(  2, 25,  2) =             0.7393562394513880
  ws(  3, 25,  2) =             0.4495232908644030
  ws(  4, 25,  2) =            -0.9808524438537990
  ws(  5, 25,  2) =            -0.7670184395260810
  ws(  6, 25,  2) =             1.0301358592548100
  ws(  7, 25,  2) =             1.4218339602812500
  ws(  8, 25,  2) =            -0.4268598625758530
  ws(  9, 25,  2) =             0.4015492531693480
  ws( 10, 25,  2) =            -0.9034368082633319
  ws( 11, 25,  2) =            -0.3054325531923070
  ws( 12, 25,  2) =             0.0835735314850221
  ws( 13, 25,  2) =             0.4124468580693650
  ws( 14, 25,  2) =            -0.8156620597440560
  ws( 15, 25,  2) =            -0.7925557417528940
  ws( 16, 25,  2) =             0.4971713121494250
  ws( 17, 25,  2) =             0.5008148717271260
  ws( 18, 25,  2) =             0.4053439645942530
  ws( 19, 25,  2) =            -0.5427932170391350
  ws( 20, 25,  2) =             0.2305189497647070
  ws( 21, 25,  2) =            -0.4354296778218940
  ws( 22, 25,  2) =            -0.8037276028721390
  ws( 23, 25,  2) =             0.0233870107922098
  ws( 24, 25,  2) =            -0.3292533342066400
  ws( 25, 25,  2) =            -0.3140101830955630
  ws( 26, 25,  2) =             0.2578720745989560
  ws( 27, 25,  2) =            -0.3516408377025240
  ws( 28, 25,  2) =             0.1391162278025730
  ws( 29, 25,  2) =             0.0917971965226645
  ws( 30, 25,  2) =            -0.0072720288441096
  ws( 31, 25,  2) =             0.9199087232568960
  ws( 32, 25,  2) =            -1.5329847243569901
  ws( 33, 25,  2) =             0.2815907362168220
  ws( 34, 25,  2) =            -0.5106482919229151
  ws( 35, 25,  2) =             0.9515973294058530
  ws( 36, 25,  2) =             1.0396265462310701
  ws( 37, 25,  2) =            -0.7033829826618500
  ws( 38, 25,  2) =            -0.0795813428896373
  ws( 39, 25,  2) =            -0.0478849956514737
  ws( 40, 25,  2) =            -0.3848831569435790
  ws( 41, 25,  2) =             1.1560014642445799
  ws( 42, 25,  2) =             0.0087808533046853
  ws( 43, 25,  2) =            -0.1656639436185860
  ws( 44, 25,  2) =             1.0977813670682799
  ws( 45, 25,  2) =             0.3168250656529610
  ws( 46, 25,  2) =             0.2774290845243610
  ws( 47, 25,  2) =            -0.8941332631446620
  ws( 48, 25,  2) =            -0.1068923889610530
  ws( 49, 25,  2) =            -0.4704387347437340
  ws( 50, 25,  2) =             0.5042966259859620
  ws(  1, 26,  2) =            -0.0653197207678785
  ws(  2, 26,  2) =             0.5364200128265100
  ws(  3, 26,  2) =             0.6901382533781660
  ws(  4, 26,  2) =            -0.7501971556169020
  ws(  5, 26,  2) =             0.4809600702541150
  ws(  6, 26,  2) =             0.7127994146150280
  ws(  7, 26,  2) =            -0.8454821756556750
  ws(  8, 26,  2) =            -1.1749842432925499
  ws(  9, 26,  2) =            -0.8542047100650210
  ws( 10, 26,  2) =            -0.7535349084339800
  ws( 11, 26,  2) =            -0.8615119870225080
  ws( 12, 26,  2) =            -0.2050133171912090
  ws( 13, 26,  2) =             0.6009995275021300
  ws( 14, 26,  2) =             0.6578393054882580
  ws( 15, 26,  2) =            -0.2150027946657390
  ws( 16, 26,  2) =            -0.2372317277282090
  ws( 17, 26,  2) =             0.8043944799714200
  ws( 18, 26,  2) =            -0.1274149434366090
  ws( 19, 26,  2) =             0.5021566657327370
  ws( 20, 26,  2) =            -0.8158630630673660
  ws( 21, 26,  2) =            -0.4112482958643270
  ws( 22, 26,  2) =             0.0065666630584961
  ws( 23, 26,  2) =            -0.8650129940262650
  ws( 24, 26,  2) =             0.0000847763081963
  ws( 25, 26,  2) =             0.8646801923540191
  ws( 26, 26,  2) =            -0.3923310380959870
  ws( 27, 26,  2) =            -0.2389095595142870
  ws( 28, 26,  2) =            -0.2938629354739910
  ws( 29, 26,  2) =             0.6272608946467439
  ws( 30, 26,  2) =            -0.7781723588152860
  ws( 31, 26,  2) =            -0.7597824230737860
  ws( 32, 26,  2) =             0.7527417671084849
  ws( 33, 26,  2) =            -0.2194727308364320
  ws( 34, 26,  2) =             0.9075535290711950
  ws( 35, 26,  2) =             0.3842195853541050
  ws( 36, 26,  2) =             0.7025418045993410
  ws( 37, 26,  2) =            -0.2894110526731600
  ws( 38, 26,  2) =             0.9360472296620300
  ws( 39, 26,  2) =            -0.7186003279465020
  ws( 40, 26,  2) =            -1.6082945468539200
  ws( 41, 26,  2) =             0.7882775392060660
  ws( 42, 26,  2) =             1.0518983842881999
  ws( 43, 26,  2) =            -0.1005873411697100
  ws( 44, 26,  2) =            -0.3989179536831130
  ws( 45, 26,  2) =            -0.0046047770711371
  ws( 46, 26,  2) =             0.6363742917106550
  ws( 47, 26,  2) =             0.0037221567070816
  ws( 48, 26,  2) =            -0.7988498618859600
  ws( 49, 26,  2) =            -0.5477742950645430
  ws( 50, 26,  2) =             0.1600532554406860
  ws(  1, 27,  2) =             0.0026597846488495
  ws(  2, 27,  2) =            -0.6697957648946710
  ws(  3, 27,  2) =            -0.7175340409846220
  ws(  4, 27,  2) =            -0.5847742912043840
  ws(  5, 27,  2) =            -0.6270746679714740
  ws(  6, 27,  2) =            -0.3897088174614960
  ws(  7, 27,  2) =             0.2921136283287210
  ws(  8, 27,  2) =            -0.3554461874391660
  ws(  9, 27,  2) =            -0.8969451608725850
  ws( 10, 27,  2) =            -0.3766667712510800
  ws( 11, 27,  2) =             0.1695702594079820
  ws( 12, 27,  2) =             0.5184100256496640
  ws( 13, 27,  2) =            -0.1364006945920760
  ws( 14, 27,  2) =             0.5811068596717190
  ws( 15, 27,  2) =             0.1327646996196510
  ws( 16, 27,  2) =            -0.5450497013554920
  ws( 17, 27,  2) =            -0.3192330818760380
  ws( 18, 27,  2) =            -0.1921923935801560
  ws( 19, 27,  2) =             1.1069716107710901
  ws( 20, 27,  2) =            -2.2313382210867001
  ws( 21, 27,  2) =            -1.9432740925420500
  ws( 22, 27,  2) =            -0.9545223339299950
  ws( 23, 27,  2) =            -0.1584065558676040
  ws( 24, 27,  2) =             0.4854585985745530
  ws( 25, 27,  2) =             0.0157082886165895
  ws( 26, 27,  2) =            -1.0226338615823301
  ws( 27, 27,  2) =             0.2451685838084250
  ws( 28, 27,  2) =            -0.7538750722456780
  ws( 29, 27,  2) =             0.7866016228466240
  ws( 30, 27,  2) =            -0.2757687526982600
  ws( 31, 27,  2) =             0.5456605767854280
  ws( 32, 27,  2) =            -0.6671673015406170
  ws( 33, 27,  2) =             1.1452990178076099
  ws( 34, 27,  2) =             1.0101124797527601
  ws( 35, 27,  2) =            -1.2401061548814600
  ws( 36, 27,  2) =             0.4050898758921570
  ws( 37, 27,  2) =             0.1605032129677690
  ws( 38, 27,  2) =            -0.2998353771489900
  ws( 39, 27,  2) =            -0.1021922189795980
  ws( 40, 27,  2) =            -2.4551880750273298
  ws( 41, 27,  2) =             0.4511915451213280
  ws( 42, 27,  2) =             0.3760474617453510
  ws( 43, 27,  2) =            -1.4433109272085900
  ws( 44, 27,  2) =            -0.5006835249712520
  ws( 45, 27,  2) =             1.2703259430945200
  ws( 46, 27,  2) =             0.2610298614083340
  ws( 47, 27,  2) =            -0.6570244314008030
  ws( 48, 27,  2) =            -0.0887437370453034
  ws( 49, 27,  2) =             0.2741949679131290
  ws( 50, 27,  2) =             0.4900330037452320
  ws(  1, 28,  2) =             0.7932989758785400
  ws(  2, 28,  2) =            -0.0113406082407752
  ws(  3, 28,  2) =            -0.1448164320606380
  ws(  4, 28,  2) =             0.3353061444600750
  ws(  5, 28,  2) =             0.5750157208061391
  ws(  6, 28,  2) =            -0.8492861078781360
  ws(  7, 28,  2) =            -0.4704637402656400
  ws(  8, 28,  2) =             0.2643066445654190
  ws(  9, 28,  2) =             0.2475577631007800
  ws( 10, 28,  2) =             0.3162054738411010
  ws( 11, 28,  2) =             1.1091204839924300
  ws( 12, 28,  2) =            -0.5966565759669820
  ws( 13, 28,  2) =             0.6496909984331340
  ws( 14, 28,  2) =            -1.0897094010185999
  ws( 15, 28,  2) =             0.4742217659845840
  ws( 16, 28,  2) =            -0.6901704303053871
  ws( 17, 28,  2) =             0.3479612381951770
  ws( 18, 28,  2) =            -0.1983816206791450
  ws( 19, 28,  2) =            -1.2977250847168500
  ws( 20, 28,  2) =             0.6969340420890100
  ws( 21, 28,  2) =             0.0738703678010249
  ws( 22, 28,  2) =             0.8730681883341780
  ws( 23, 28,  2) =             0.5310852395473430
  ws( 24, 28,  2) =            -0.4189916741474310
  ws( 25, 28,  2) =            -0.3617983817438310
  ws( 26, 28,  2) =             0.6281969041445790
  ws( 27, 28,  2) =            -0.7296261867682030
  ws( 28, 28,  2) =             0.4169135757004790
  ws( 29, 28,  2) =             0.8080312477325839
  ws( 30, 28,  2) =             0.5313315241010510
  ws( 31, 28,  2) =             0.7172987487063970
  ws( 32, 28,  2) =             1.1482842196603700
  ws( 33, 28,  2) =            -0.1241573151836240
  ws( 34, 28,  2) =            -0.6449890708698750
  ws( 35, 28,  2) =            -0.4243500496767810
  ws( 36, 28,  2) =            -0.7849511708021970
  ws( 37, 28,  2) =            -0.0999515423092808
  ws( 38, 28,  2) =            -0.7677100913085830
  ws( 39, 28,  2) =             0.4901917655844980
  ws( 40, 28,  2) =             0.7882585185594110
  ws( 41, 28,  2) =            -0.6097340087519020
  ws( 42, 28,  2) =            -0.1941929719537650
  ws( 43, 28,  2) =             1.5812642886935400
  ws( 44, 28,  2) =             0.7079350200042370
  ws( 45, 28,  2) =            -0.3753831125464830
  ws( 46, 28,  2) =             0.3978310475773100
  ws( 47, 28,  2) =            -0.4952913374618470
  ws( 48, 28,  2) =            -1.3291469880938300
  ws( 49, 28,  2) =            -0.2605904581179200
  ws( 50, 28,  2) =            -0.1868318861949520
  ws(  1, 29,  2) =             0.2187716572680170
  ws(  2, 29,  2) =            -0.2226808217705720
  ws(  3, 29,  2) =             0.1120377586810280
  ws(  4, 29,  2) =             0.1175447074310420
  ws(  5, 29,  2) =             0.1023254870142820
  ws(  6, 29,  2) =            -0.2656406756128770
  ws(  7, 29,  2) =            -0.6521529482047300
  ws(  8, 29,  2) =            -2.6078223955194000
  ws(  9, 29,  2) =            -0.9719222056626380
  ws( 10, 29,  2) =             1.2785144291385699
  ws( 11, 29,  2) =            -1.0742979644400299
  ws( 12, 29,  2) =            -1.3249766991032299
  ws( 13, 29,  2) =             0.5268621373575100
  ws( 14, 29,  2) =             1.7544305742432200
  ws( 15, 29,  2) =            -2.2584357705340299
  ws( 16, 29,  2) =            -0.4444049628851210
  ws( 17, 29,  2) =             0.4374572574898500
  ws( 18, 29,  2) =            -0.5530538017766420
  ws( 19, 29,  2) =             1.8469212133969499
  ws( 20, 29,  2) =            -3.2568116328617398
  ws( 21, 29,  2) =            -1.2069256868970699
  ws( 22, 29,  2) =            -1.5654995271717900
  ws( 23, 29,  2) =            -0.8446750931633690
  ws( 24, 29,  2) =            -0.1661069515380520
  ws( 25, 29,  2) =             0.0592817899541977
  ws( 26, 29,  2) =             0.0636219141534964
  ws( 27, 29,  2) =             0.6642238940204300
  ws( 28, 29,  2) =            -0.3492948186288990
  ws( 29, 29,  2) =             1.5188435593664600
  ws( 30, 29,  2) =            -0.9396584300655020
  ws( 31, 29,  2) =            -0.3989225389868170
  ws( 32, 29,  2) =             0.5429972789320300
  ws( 33, 29,  2) =             0.1519581249377900
  ws( 34, 29,  2) =            -0.1080980242584280
  ws( 35, 29,  2) =             0.1348077822352650
  ws( 36, 29,  2) =             0.1234792473760030
  ws( 37, 29,  2) =            -1.4709553038401799
  ws( 38, 29,  2) =            -0.2912815047470730
  ws( 39, 29,  2) =            -0.6409473803164620
  ws( 40, 29,  2) =            -1.7370194018913501
  ws( 41, 29,  2) =            -0.9418980910244660
  ws( 42, 29,  2) =            -0.3184487536770860
  ws( 43, 29,  2) =            -1.6391722919641700
  ws( 44, 29,  2) =             1.3741303690661999
  ws( 45, 29,  2) =            -0.1384671791115190
  ws( 46, 29,  2) =            -0.5620404428726660
  ws( 47, 29,  2) =             0.7833318120543390
  ws( 48, 29,  2) =             0.3430228362844110
  ws( 49, 29,  2) =            -1.2060259981455801
  ws( 50, 29,  2) =             0.5739812623383900
  ws(  1, 30,  2) =             0.1756138736379670
  ws(  2, 30,  2) =            -0.7896674057859540
  ws(  3, 30,  2) =             0.9318454818922040
  ws(  4, 30,  2) =            -0.0794040638139470
  ws(  5, 30,  2) =            -0.1280147505556690
  ws(  6, 30,  2) =             0.5845002882046010
  ws(  7, 30,  2) =            -0.2291578144174400
  ws(  8, 30,  2) =             3.1241478809102099
  ws(  9, 30,  2) =            -0.2937307681780510
  ws( 10, 30,  2) =            -1.5097403605986801
  ws( 11, 30,  2) =             1.8094366882904600
  ws( 12, 30,  2) =             0.5991409769258300
  ws( 13, 30,  2) =            -1.4416658083376099
  ws( 14, 30,  2) =            -1.2186705717575499
  ws( 15, 30,  2) =             2.6232040858501802
  ws( 16, 30,  2) =            -0.8313349635102421
  ws( 17, 30,  2) =             1.0586846383092900
  ws( 18, 30,  2) =             0.5563827615695850
  ws( 19, 30,  2) =            -2.1867211031145901
  ws( 20, 30,  2) =             1.5483399522935100
  ws( 21, 30,  2) =             1.5733439545677299
  ws( 22, 30,  2) =             1.6084648533743100
  ws( 23, 30,  2) =            -0.1160494857642010
  ws( 24, 30,  2) =            -0.4329226002148000
  ws( 25, 30,  2) =            -0.8013864488804970
  ws( 26, 30,  2) =             0.9996110054573490
  ws( 27, 30,  2) =            -1.7525646649145099
  ws( 28, 30,  2) =             0.5279070520479960
  ws( 29, 30,  2) =            -0.7347109132841561
  ws( 30, 30,  2) =            -0.0050715947187489
  ws( 31, 30,  2) =            -0.9105510244996060
  ws( 32, 30,  2) =            -0.1675362542497440
  ws( 33, 30,  2) =            -0.3378704010047580
  ws( 34, 30,  2) =             0.7503692936225530
  ws( 35, 30,  2) =             0.8476021880576130
  ws( 36, 30,  2) =            -1.4369618295683000
  ws( 37, 30,  2) =             0.6035672029231900
  ws( 38, 30,  2) =             0.3195472437638660
  ws( 39, 30,  2) =            -0.2400129781152440
  ws( 40, 30,  2) =             1.6411739173733499
  ws( 41, 30,  2) =            -0.8221584358709580
  ws( 42, 30,  2) =            -0.1339960677978620
  ws( 43, 30,  2) =             0.4804039343846480
  ws( 44, 30,  2) =             0.3701716374443300
  ws( 45, 30,  2) =            -0.1779350150145900
  ws( 46, 30,  2) =             0.4025311133993440
  ws( 47, 30,  2) =             0.3824776780476270
  ws( 48, 30,  2) =            -0.4757121820888190
  ws( 49, 30,  2) =             1.5635547779735099
  ws( 50, 30,  2) =            -0.3326339332009800
  ws(  1, 31,  2) =            -0.1526327480698910
  ws(  2, 31,  2) =            -0.1179140486719170
  ws(  3, 31,  2) =             0.9814915090590490
  ws(  4, 31,  2) =            -0.3491750301290130
  ws(  5, 31,  2) =            -0.0787643779249160
  ws(  6, 31,  2) =            -0.0522367231571940
  ws(  7, 31,  2) =             0.2498402062565010
  ws(  8, 31,  2) =             0.5337805981633030
  ws(  9, 31,  2) =            -0.4406613801583970
  ws( 10, 31,  2) =            -0.8846232188284910
  ws( 11, 31,  2) =             0.5919929729602950
  ws( 12, 31,  2) =             0.8266241655655830
  ws( 13, 31,  2) =             0.2609577563160190
  ws( 14, 31,  2) =            -0.5819396575809250
  ws( 15, 31,  2) =             0.7160075601261270
  ws( 16, 31,  2) =             0.4334069119707540
  ws( 17, 31,  2) =            -0.7322797210669080
  ws( 18, 31,  2) =             0.4821272051688590
  ws( 19, 31,  2) =            -0.5719453908204740
  ws( 20, 31,  2) =             0.1841149408769980
  ws( 21, 31,  2) =             1.0818868909384900
  ws( 22, 31,  2) =            -0.5717940754457910
  ws( 23, 31,  2) =             0.0120871315371323
  ws( 24, 31,  2) =            -0.5785681127718730
  ws( 25, 31,  2) =             0.2589390100558550
  ws( 26, 31,  2) =             0.6229572848052080
  ws( 27, 31,  2) =            -1.0099363662706800
  ws( 28, 31,  2) =            -0.7311411252670440
  ws( 29, 31,  2) =             0.3605862833652230
  ws( 30, 31,  2) =             0.7704616007295479
  ws( 31, 31,  2) =             0.4672415563234030
  ws( 32, 31,  2) =            -0.0980732465782735
  ws( 33, 31,  2) =            -1.1022946858271101
  ws( 34, 31,  2) =            -0.6685174680558350
  ws( 35, 31,  2) =             0.5312182173328650
  ws( 36, 31,  2) =            -0.3690560309520070
  ws( 37, 31,  2) =             0.1564982762935260
  ws( 38, 31,  2) =            -0.0700193801328941
  ws( 39, 31,  2) =            -0.3458847192048120
  ws( 40, 31,  2) =             1.4766119836963001
  ws( 41, 31,  2) =             0.1636491598484090
  ws( 42, 31,  2) =             0.3232224694046540
  ws( 43, 31,  2) =             1.1129655385546700
  ws( 44, 31,  2) =             0.0388577936304746
  ws( 45, 31,  2) =            -0.6642892047886170
  ws( 46, 31,  2) =            -0.1757799641031850
  ws( 47, 31,  2) =             0.0297587452424211
  ws( 48, 31,  2) =             1.0097380680493400
  ws( 49, 31,  2) =             0.3076718849493860
  ws( 50, 31,  2) =             0.4635372508308150
  ws(  1, 32,  2) =            -0.7311609707759290
  ws(  2, 32,  2) =             0.9536218024565279
  ws(  3, 32,  2) =            -0.1488765874394600
  ws(  4, 32,  2) =             1.0147208064188300
  ws(  5, 32,  2) =             0.3942086877557790
  ws(  6, 32,  2) =            -0.1707735589486020
  ws(  7, 32,  2) =             0.1869281341460310
  ws(  8, 32,  2) =             1.3470267167782000
  ws(  9, 32,  2) =             0.1745038380758440
  ws( 10, 32,  2) =             0.4152828428237380
  ws( 11, 32,  2) =            -0.6671193645257900
  ws( 12, 32,  2) =             0.3558348370040130
  ws( 13, 32,  2) =            -1.1267550314613599
  ws( 14, 32,  2) =             0.3123901644628790
  ws( 15, 32,  2) =            -1.3250772182343900
  ws( 16, 32,  2) =            -0.1095729422497190
  ws( 17, 32,  2) =             0.3605595656855290
  ws( 18, 32,  2) =             0.2856413290998360
  ws( 19, 32,  2) =             1.2411596774831599
  ws( 20, 32,  2) =            -0.6013696225894610
  ws( 21, 32,  2) =            -1.0186886154059100
  ws( 22, 32,  2) =             0.0867126448372827
  ws( 23, 32,  2) =             0.2921155709444440
  ws( 24, 32,  2) =             1.0297750402414800
  ws( 25, 32,  2) =             0.7064007814035330
  ws( 26, 32,  2) =             0.7524601579450370
  ws( 27, 32,  2) =            -0.5458581788866740
  ws( 28, 32,  2) =            -0.6480169168494210
  ws( 29, 32,  2) =            -0.1508034829602380
  ws( 30, 32,  2) =             0.2443742912376900
  ws( 31, 32,  2) =             0.3456444852966420
  ws( 32, 32,  2) =            -0.0068154093473478
  ws( 33, 32,  2) =             0.6346736687569789
  ws( 34, 32,  2) =             0.5703201246271120
  ws( 35, 32,  2) =            -0.7356729236495990
  ws( 36, 32,  2) =            -0.8016640947925320
  ws( 37, 32,  2) =            -0.2963588360218290
  ws( 38, 32,  2) =             0.0452913195676035
  ws( 39, 32,  2) =             0.6623297654640730
  ws( 40, 32,  2) =            -0.6937179245439000
  ws( 41, 32,  2) =            -0.2171486340440840
  ws( 42, 32,  2) =            -0.7094815317884970
  ws( 43, 32,  2) =             0.1593688186264490
  ws( 44, 32,  2) =             0.8962277242111950
  ws( 45, 32,  2) =             0.9405548034179310
  ws( 46, 32,  2) =             0.3208885181856830
  ws( 47, 32,  2) =            -0.7663515182681380
  ws( 48, 32,  2) =            -0.8332630892556510
  ws( 49, 32,  2) =             0.3380537376483580
  ws( 50, 32,  2) =             0.9557576777155230
  ws(  1, 33,  2) =             0.7584106152028510
  ws(  2, 33,  2) =             0.7463922387191290
  ws(  3, 33,  2) =             0.3224219002643480
  ws(  4, 33,  2) =            -0.9477067219590209
  ws(  5, 33,  2) =            -0.5222927091150520
  ws(  6, 33,  2) =             0.1980323940135640
  ws(  7, 33,  2) =             0.4610473864805520
  ws(  8, 33,  2) =            -0.7742556612469860
  ws(  9, 33,  2) =            -0.2041611552329180
  ws( 10, 33,  2) =             0.0677032688475243
  ws( 11, 33,  2) =             0.1022584262153210
  ws( 12, 33,  2) =             0.9350293734158810
  ws( 13, 33,  2) =            -0.1921584963895710
  ws( 14, 33,  2) =            -0.1176413630759820
  ws( 15, 33,  2) =            -0.5540783831456260
  ws( 16, 33,  2) =             0.9452345699323120
  ws( 17, 33,  2) =            -0.9657452740426600
  ws( 18, 33,  2) =            -0.1424910194508490
  ws( 19, 33,  2) =             0.4220181800924070
  ws( 20, 33,  2) =             0.2869453843598790
  ws( 21, 33,  2) =             0.9535511056539020
  ws( 22, 33,  2) =             0.4064999676632950
  ws( 23, 33,  2) =            -0.4084050511436680
  ws( 24, 33,  2) =            -0.6128439761757970
  ws( 25, 33,  2) =             0.8701642674329360
  ws( 26, 33,  2) =            -0.5634511773468330
  ws( 27, 33,  2) =             0.7417114737192830
  ws( 28, 33,  2) =             0.6163282847559430
  ws( 29, 33,  2) =            -0.8663854092057400
  ws( 30, 33,  2) =            -1.0145451223901600
  ws( 31, 33,  2) =             0.2593694623474200
  ws( 32, 33,  2) =             1.5430752526049201
  ws( 33, 33,  2) =            -0.7640934994533870
  ws( 34, 33,  2) =            -0.1766779894620520
  ws( 35, 33,  2) =             0.1372274446289640
  ws( 36, 33,  2) =            -0.0040130033437588
  ws( 37, 33,  2) =            -0.0753281789735009
  ws( 38, 33,  2) =             0.7458878551221690
  ws( 39, 33,  2) =            -0.6391726202119420
  ws( 40, 33,  2) =            -0.7593854099814620
  ws( 41, 33,  2) =             0.4732473503851740
  ws( 42, 33,  2) =            -0.5030633698003130
  ws( 43, 33,  2) =             0.8688747989329110
  ws( 44, 33,  2) =            -0.5237485961350140
  ws( 45, 33,  2) =            -0.9787105289587890
  ws( 46, 33,  2) =             0.7210233914871560
  ws( 47, 33,  2) =            -0.0145776904329359
  ws( 48, 33,  2) =            -1.0740277573076400
  ws( 49, 33,  2) =             0.7422000097444280
  ws( 50, 33,  2) =             0.3116268770580330
  ws(  1, 34,  2) =            -0.1885704837206260
  ws(  2, 34,  2) =             0.3674020327993790
  ws(  3, 34,  2) =             0.4444992872816210
  ws(  4, 34,  2) =            -0.0923530950584036
  ws(  5, 34,  2) =            -0.2608386643408470
  ws(  6, 34,  2) =            -0.0213913917289429
  ws(  7, 34,  2) =             0.3712441299279720
  ws(  8, 34,  2) =             0.6708060394330559
  ws(  9, 34,  2) =             0.6226864521889930
  ws( 10, 34,  2) =            -0.3333659754105190
  ws( 11, 34,  2) =             0.2095112495103650
  ws( 12, 34,  2) =             1.0280153454202301
  ws( 13, 34,  2) =            -0.2325547566075490
  ws( 14, 34,  2) =            -0.0147874219339398
  ws( 15, 34,  2) =             0.5634225849695510
  ws( 16, 34,  2) =             0.1470456565591690
  ws( 17, 34,  2) =            -0.1368773838928390
  ws( 18, 34,  2) =            -0.0324309274984500
  ws( 19, 34,  2) =            -0.9615418990587250
  ws( 20, 34,  2) =             0.7246324432530580
  ws( 21, 34,  2) =             1.3499402285063000
  ws( 22, 34,  2) =            -0.3382855303003650
  ws( 23, 34,  2) =             0.8768902652961270
  ws( 24, 34,  2) =             0.9867769867047590
  ws( 25, 34,  2) =            -0.2678531857739710
  ws( 26, 34,  2) =             0.7013337245667510
  ws( 27, 34,  2) =             1.0282323927929800
  ws( 28, 34,  2) =            -0.8702202049936740
  ws( 29, 34,  2) =             0.0265200527167171
  ws( 30, 34,  2) =            -0.8054462188496930
  ws( 31, 34,  2) =             1.1019557625348799
  ws( 32, 34,  2) =             1.4616093960940200
  ws( 33, 34,  2) =            -0.9413504266784470
  ws( 34, 34,  2) =            -0.6938430199171340
  ws( 35, 34,  2) =            -0.7087190102452680
  ws( 36, 34,  2) =             0.9759097187699010
  ws( 37, 34,  2) =            -0.3340624524129290
  ws( 38, 34,  2) =            -0.8766426398624420
  ws( 39, 34,  2) =            -0.1650343334511470
  ws( 40, 34,  2) =             0.7731225969097431
  ws( 41, 34,  2) =            -0.8473182393961211
  ws( 42, 34,  2) =             0.8661272123080460
  ws( 43, 34,  2) =             0.5582914311399330
  ws( 44, 34,  2) =            -0.9946465458348340
  ws( 45, 34,  2) =            -0.5818325184590920
  ws( 46, 34,  2) =            -0.2388102182614460
  ws( 47, 34,  2) =            -0.6315440444310190
  ws( 48, 34,  2) =             0.4487230002062160
  ws( 49, 34,  2) =            -0.5823926627853750
  ws( 50, 34,  2) =            -0.9091386561414690
  ws(  1, 35,  2) =            -0.6259753883659021
  ws(  2, 35,  2) =             0.5524410004990210
  ws(  3, 35,  2) =            -0.9291124059459320
  ws(  4, 35,  2) =            -0.8459481253442550
  ws(  5, 35,  2) =             0.6698921316995260
  ws(  6, 35,  2) =            -0.4632723605511380
  ws(  7, 35,  2) =             0.3155168325174110
  ws(  8, 35,  2) =             1.0204595616217000
  ws(  9, 35,  2) =             0.7267932570159320
  ws( 10, 35,  2) =            -0.6907176356033971
  ws( 11, 35,  2) =            -0.7825628964923500
  ws( 12, 35,  2) =            -0.2842239709471980
  ws( 13, 35,  2) =            -0.2256358812739940
  ws( 14, 35,  2) =             0.7308448367731930
  ws( 15, 35,  2) =             0.5619510347052310
  ws( 16, 35,  2) =             1.1471494545882699
  ws( 17, 35,  2) =             0.1423119356695450
  ws( 18, 35,  2) =            -1.0102546385048601
  ws( 19, 35,  2) =            -0.1889058305184760
  ws( 20, 35,  2) =            -0.7052144962221250
  ws( 21, 35,  2) =            -0.0829851603100342
  ws( 22, 35,  2) =             0.9488190413751409
  ws( 23, 35,  2) =            -0.6945714082265260
  ws( 24, 35,  2) =             0.0435673863179386
  ws( 25, 35,  2) =             0.7834445744329260
  ws( 26, 35,  2) =            -0.4581004457323230
  ws( 27, 35,  2) =             0.0535360197700662
  ws( 28, 35,  2) =             0.6159542350074770
  ws( 29, 35,  2) =            -0.2889104408247270
  ws( 30, 35,  2) =            -0.4907931772535590
  ws( 31, 35,  2) =             0.4464410697524930
  ws( 32, 35,  2) =             0.7326031111800551
  ws( 33, 35,  2) =             0.1986089786387620
  ws( 34, 35,  2) =             0.5366359582266520
  ws( 35, 35,  2) =             0.9371041263344710
  ws( 36, 35,  2) =            -0.4729678217055540
  ws( 37, 35,  2) =             0.4371287084729370
  ws( 38, 35,  2) =             0.4592072154309600
  ws( 39, 35,  2) =             0.7110510474298010
  ws( 40, 35,  2) =            -0.3218747901795000
  ws( 41, 35,  2) =             0.5035601388332790
  ws( 42, 35,  2) =            -0.4854158721137110
  ws( 43, 35,  2) =            -0.5376091545208880
  ws( 44, 35,  2) =             0.4369708083488350
  ws( 45, 35,  2) =            -0.6394658691224691
  ws( 46, 35,  2) =             0.1095252056768120
  ws( 47, 35,  2) =            -0.3290940190851530
  ws( 48, 35,  2) =            -0.4451322221078040
  ws( 49, 35,  2) =             0.9180193743100020
  ws( 50, 35,  2) =            -0.7328597245784910
  ws(  1, 36,  2) =             0.0373120086343730
  ws(  2, 36,  2) =            -0.6611924658707730
  ws(  3, 36,  2) =             0.4640621979560290
  ws(  4, 36,  2) =             0.2514321722570470
  ws(  5, 36,  2) =             0.7818258745717011
  ws(  6, 36,  2) =            -0.9108473403216850
  ws(  7, 36,  2) =             1.0333465036383500
  ws(  8, 36,  2) =            -1.4941207083241199
  ws(  9, 36,  2) =             0.8157719754002740
  ws( 10, 36,  2) =            -0.2028127589451650
  ws( 11, 36,  2) =            -0.7949140933982300
  ws( 12, 36,  2) =             0.7983708238705000
  ws( 13, 36,  2) =            -0.2530494224549090
  ws( 14, 36,  2) =             0.9861831139106511
  ws( 15, 36,  2) =            -0.5205587262531480
  ws( 16, 36,  2) =             0.3677578206011680
  ws( 17, 36,  2) =            -0.0753457754062594
  ws( 18, 36,  2) =            -0.9501009234590549
  ws( 19, 36,  2) =            -0.5192967894130480
  ws( 20, 36,  2) =             0.2858386804208000
  ws( 21, 36,  2) =             1.5732499350454301
  ws( 22, 36,  2) =             0.1563338701017990
  ws( 23, 36,  2) =             0.8973519526779140
  ws( 24, 36,  2) =            -0.7571663448733580
  ws( 25, 36,  2) =             0.5844928766741470
  ws( 26, 36,  2) =             0.2867889122731660
  ws( 27, 36,  2) =             2.3523699203252599
  ws( 28, 36,  2) =             0.7956704507037020
  ws( 29, 36,  2) =             0.8721722757720211
  ws( 30, 36,  2) =             0.2168342038982630
  ws( 31, 36,  2) =            -0.6152125898416850
  ws( 32, 36,  2) =             0.7300059278532161
  ws( 33, 36,  2) =            -0.4439534785083420
  ws( 34, 36,  2) =             0.3090110990886110
  ws( 35, 36,  2) =            -0.4163073092523950
  ws( 36, 36,  2) =             0.9734032685480380
  ws( 37, 36,  2) =            -0.3794622226152690
  ws( 38, 36,  2) =            -0.4889007278946440
  ws( 39, 36,  2) =             0.7838467565837580
  ws( 40, 36,  2) =             1.5320641456097901
  ws( 41, 36,  2) =             0.8199230181560850
  ws( 42, 36,  2) =             1.0995528897080000
  ws( 43, 36,  2) =             0.4017264494820780
  ws( 44, 36,  2) =            -0.3075448438039040
  ws( 45, 36,  2) =            -0.5924010311404030
  ws( 46, 36,  2) =             0.5327850459211310
  ws( 47, 36,  2) =            -0.8856201570815140
  ws( 48, 36,  2) =            -0.6507005118650940
  ws( 49, 36,  2) =            -0.6865289935929190
  ws( 50, 36,  2) =             0.5182599217956890
  ws(  1, 37,  2) =            -0.9327148756471190
  ws(  2, 37,  2) =             0.6681150695375609
  ws(  3, 37,  2) =            -0.2767431743925620
  ws(  4, 37,  2) =            -0.5611123881534670
  ws(  5, 37,  2) =             0.0469892543263058
  ws(  6, 37,  2) =            -0.9021207381960969
  ws(  7, 37,  2) =            -0.8059449072266470
  ws(  8, 37,  2) =            -0.2348162258709350
  ws(  9, 37,  2) =             0.8193305442759390
  ws( 10, 37,  2) =             0.7497658417874710
  ws( 11, 37,  2) =             1.1849816078644000
  ws( 12, 37,  2) =            -0.7271611831263300
  ws( 13, 37,  2) =             0.3960837358371270
  ws( 14, 37,  2) =            -1.2005854357542900
  ws( 15, 37,  2) =            -0.0539637682224177
  ws( 16, 37,  2) =             0.2974650966748440
  ws( 17, 37,  2) =             0.9722584220642330
  ws( 18, 37,  2) =            -0.3901226253395500
  ws( 19, 37,  2) =            -1.6635672620379800
  ws( 20, 37,  2) =             2.9857352398773300
  ws( 21, 37,  2) =             1.2153920891522301
  ws( 22, 37,  2) =             1.6934811023722500
  ws( 23, 37,  2) =             0.4203869979219190
  ws( 24, 37,  2) =             0.4023131393888500
  ws( 25, 37,  2) =            -0.6328129611574460
  ws( 26, 37,  2) =            -0.4160495170220000
  ws( 27, 37,  2) =             1.4136261337737901
  ws( 28, 37,  2) =             0.0702174864914150
  ws( 29, 37,  2) =             0.3797249290914120
  ws( 30, 37,  2) =            -0.5858679958270750
  ws( 31, 37,  2) =             0.8873041835286470
  ws( 32, 37,  2) =             1.8363916860004701
  ws( 33, 37,  2) =            -0.0925991344980869
  ws( 34, 37,  2) =            -0.5239143916044910
  ws( 35, 37,  2) =             0.1768837287358140
  ws( 36, 37,  2) =            -0.5141648832136270
  ws( 37, 37,  2) =             0.5347770873842790
  ws( 38, 37,  2) =            -0.1558443319910160
  ws( 39, 37,  2) =             0.1097576448191410
  ws( 40, 37,  2) =             1.8179710102731299
  ws( 41, 37,  2) =             0.2572044502407360
  ws( 42, 37,  2) =             0.9820221168925209
  ws( 43, 37,  2) =             0.0187000057856178
  ws( 44, 37,  2) =             0.0604371706207575
  ws( 45, 37,  2) =            -0.3138588458573770
  ws( 46, 37,  2) =             0.2476833947826440
  ws( 47, 37,  2) =             0.3995425780900880
  ws( 48, 37,  2) =             0.5021586286911790
  ws( 49, 37,  2) =             0.4882566234976160
  ws( 50, 37,  2) =             0.5606565034367490
  ws(  1, 38,  2) =            -0.4846217953069100
  ws(  2, 38,  2) =            -0.9532486767002910
  ws(  3, 38,  2) =            -0.7380319088827970
  ws(  4, 38,  2) =             0.3750626808086190
  ws(  5, 38,  2) =            -0.1230175616172450
  ws(  6, 38,  2) =            -0.1617084351827930
  ws(  7, 38,  2) =             0.7067000034379000
  ws(  8, 38,  2) =             0.9717187817153420
  ws(  9, 38,  2) =             0.8069311526710290
  ws( 10, 38,  2) =            -0.6909908801233570
  ws( 11, 38,  2) =             0.1315112537744100
  ws( 12, 38,  2) =             0.3882737486663810
  ws( 13, 38,  2) =             0.5465783594328260
  ws( 14, 38,  2) =             1.0255094191471701
  ws( 15, 38,  2) =             0.9394959833136600
  ws( 16, 38,  2) =            -0.3908759306077100
  ws( 17, 38,  2) =            -0.1357951323517840
  ws( 18, 38,  2) =            -0.1041346285408080
  ws( 19, 38,  2) =             1.7756797107348901
  ws( 20, 38,  2) =            -3.0303724080393302
  ws( 21, 38,  2) =            -1.0949332496614801
  ws( 22, 38,  2) =            -1.5610473227635999
  ws( 23, 38,  2) =            -0.2119933068057880
  ws( 24, 38,  2) =            -0.0316037510294305
  ws( 25, 38,  2) =            -1.5138114292033900
  ws( 26, 38,  2) =             0.1505574980667670
  ws( 27, 38,  2) =            -2.1939805352205202
  ws( 28, 38,  2) =             0.3149535230352520
  ws( 29, 38,  2) =            -0.4767254248616610
  ws( 30, 38,  2) =             0.7965622639602190
  ws( 31, 38,  2) =            -0.1751550842910780
  ws( 32, 38,  2) =            -2.1114426360457501
  ws( 33, 38,  2) =             1.0222068908135700
  ws( 34, 38,  2) =             0.2555887327508700
  ws( 35, 38,  2) =            -1.0087783617598500
  ws( 36, 38,  2) =             0.1096010138472220
  ws( 37, 38,  2) =             0.4846152590398880
  ws( 38, 38,  2) =            -0.0732784978194947
  ws( 39, 38,  2) =             0.6979862669525509
  ws( 40, 38,  2) =            -1.2807744863448600
  ws( 41, 38,  2) =             0.6500554336603031
  ws( 42, 38,  2) =            -0.2063360258761300
  ws( 43, 38,  2) =            -0.3049126500737660
  ws( 44, 38,  2) =            -0.7725243228822520
  ws( 45, 38,  2) =             1.7119355083241501
  ws( 46, 38,  2) =            -0.3913587707177410
  ws( 47, 38,  2) =             1.0814659312181800
  ws( 48, 38,  2) =             0.9850095734645120
  ws( 49, 38,  2) =            -0.5743604765684540
  ws( 50, 38,  2) =            -0.4701173478966390
  ws(  1, 39,  2) =            -0.0434697989225475
  ws(  2, 39,  2) =            -0.2328364618836930
  ws(  3, 39,  2) =             0.1775645168339210
  ws(  4, 39,  2) =             0.5643138479175940
  ws(  5, 39,  2) =            -0.7619678389552670
  ws(  6, 39,  2) =             0.2881756943291060
  ws(  7, 39,  2) =             0.6902601489842040
  ws(  8, 39,  2) =             0.7370829836560450
  ws(  9, 39,  2) =            -0.0685464412686747
  ws( 10, 39,  2) =             0.5997449315901290
  ws( 11, 39,  2) =             0.0112302307342068
  ws( 12, 39,  2) =            -0.1845679265513380
  ws( 13, 39,  2) =             0.3325463386548440
  ws( 14, 39,  2) =            -1.1456137484251800
  ws( 15, 39,  2) =             0.4436278617626700
  ws( 16, 39,  2) =             1.0549183303054701
  ws( 17, 39,  2) =             0.6375364157247460
  ws( 18, 39,  2) =            -0.8387010892446189
  ws( 19, 39,  2) =            -1.2885737698839399
  ws( 20, 39,  2) =             0.5147324176767190
  ws( 21, 39,  2) =             1.6164076019539899
  ws( 22, 39,  2) =             0.6912044876876180
  ws( 23, 39,  2) =            -0.5445002942772050
  ws( 24, 39,  2) =            -0.7605385376330630
  ws( 25, 39,  2) =             0.5156425667595120
  ws( 26, 39,  2) =             0.0295446779358790
  ws( 27, 39,  2) =             1.7612549997507101
  ws( 28, 39,  2) =            -0.1108612560210360
  ws( 29, 39,  2) =             0.1589605374486070
  ws( 30, 39,  2) =            -0.1068718852208530
  ws( 31, 39,  2) =             0.9618361021692190
  ws( 32, 39,  2) =             1.2969117301431401
  ws( 33, 39,  2) =            -0.3514119745416540
  ws( 34, 39,  2) =            -0.2935246238946990
  ws( 35, 39,  2) =            -0.0223310570840790
  ws( 36, 39,  2) =             0.0410144124278900
  ws( 37, 39,  2) =             1.1232056878466701
  ws( 38, 39,  2) =            -0.0473094472685284
  ws( 39, 39,  2) =            -0.6938382405457590
  ws( 40, 39,  2) =             2.1901682422405000
  ws( 41, 39,  2) =            -0.6708657801086640
  ws( 42, 39,  2) =             0.2971674540767030
  ws( 43, 39,  2) =             1.6835642595794100
  ws( 44, 39,  2) =            -0.5218165693541690
  ws( 45, 39,  2) =             0.0049221765867927
  ws( 46, 39,  2) =            -0.9776108269545940
  ws( 47, 39,  2) =            -0.9133276124138150
  ws( 48, 39,  2) =            -1.1077547286178000
  ws( 49, 39,  2) =             0.2993109019519700
  ws( 50, 39,  2) =            -0.2944053469870780
  ws(  1, 40,  2) =             0.5872677044865430
  ws(  2, 40,  2) =             0.4656542669278030
  ws(  3, 40,  2) =            -0.8548288057099980
  ws(  4, 40,  2) =             0.2477771027334960
  ws(  5, 40,  2) =            -0.1745816619268000
  ws(  6, 40,  2) =            -0.7872385136136000
  ws(  7, 40,  2) =            -0.7996815775421410
  ws(  8, 40,  2) =            -1.3707304186651199
  ws(  9, 40,  2) =             0.6610600971171350
  ws( 10, 40,  2) =            -0.3708986791077090
  ws( 11, 40,  2) =            -0.0132784233352274
  ws( 12, 40,  2) =             0.5158411680812290
  ws( 13, 40,  2) =            -0.7361135746447940
  ws( 14, 40,  2) =             1.0873323392577099
  ws( 15, 40,  2) =             0.0638118375024653
  ws( 16, 40,  2) =             0.4393111569922750
  ws( 17, 40,  2) =             0.7284936716339550
  ws( 18, 40,  2) =             0.8963467689764830
  ws( 19, 40,  2) =             0.0474003038257473
  ws( 20, 40,  2) =            -0.5659228107099750
  ws( 21, 40,  2) =            -0.8882126148489830
  ws( 22, 40,  2) =            -0.9514141385161060
  ws( 23, 40,  2) =            -0.1317405167267550
  ws( 24, 40,  2) =            -0.6017647995034200
  ws( 25, 40,  2) =            -0.6823862675876970
  ws( 26, 40,  2) =             0.1442997766117120
  ws( 27, 40,  2) =             0.8363268370677790
  ws( 28, 40,  2) =             0.6555657145579090
  ws( 29, 40,  2) =            -0.1501587241164660
  ws( 30, 40,  2) =            -1.0438637602809400
  ws( 31, 40,  2) =            -0.2610038166645880
  ws( 32, 40,  2) =             0.4320928419812860
  ws( 33, 40,  2) =             0.3732686233063710
  ws( 34, 40,  2) =             0.1125593883032110
  ws( 35, 40,  2) =            -0.7168810674929590
  ws( 36, 40,  2) =             0.3276531043468990
  ws( 37, 40,  2) =            -0.2044154303227670
  ws( 38, 40,  2) =             0.7705415912084710
  ws( 39, 40,  2) =            -0.0485180285417870
  ws( 40, 40,  2) =            -0.6878665454176101
  ws( 41, 40,  2) =             0.4817108157672880
  ws( 42, 40,  2) =            -0.7532480322571939
  ws( 43, 40,  2) =             0.1944537439040610
  ws( 44, 40,  2) =            -0.2842232047981520
  ws( 45, 40,  2) =            -0.1946232727829360
  ws( 46, 40,  2) =            -0.0906396937600535
  ws( 47, 40,  2) =             0.3850677551335300
  ws( 48, 40,  2) =            -1.2480419137690100
  ws( 49, 40,  2) =            -0.7760860842130420
  ws( 50, 40,  2) =             1.0197993834058801
  ws(  1, 41,  2) =            -0.1575418923450550
  ws(  2, 41,  2) =            -0.5148372978950160
  ws(  3, 41,  2) =            -0.0064421407868077
  ws(  4, 41,  2) =             0.6926731494987060
  ws(  5, 41,  2) =             0.1392377721886030
  ws(  6, 41,  2) =            -0.5306260593693780
  ws(  7, 41,  2) =             0.0403347120142532
  ws(  8, 41,  2) =             0.5678002115860620
  ws(  9, 41,  2) =            -0.1280923625785500
  ws( 10, 41,  2) =             0.3570896140183970
  ws( 11, 41,  2) =             0.5653935646953649
  ws( 12, 41,  2) =             0.6511311596489771
  ws( 13, 41,  2) =            -0.7712714123703920
  ws( 14, 41,  2) =             0.3105338900826300
  ws( 15, 41,  2) =             0.2133746234428890
  ws( 16, 41,  2) =             0.1768295101773880
  ws( 17, 41,  2) =             0.0880123942641588
  ws( 18, 41,  2) =             0.3380702879453250
  ws( 19, 41,  2) =             0.0351063385775913
  ws( 20, 41,  2) =            -0.7563705571016330
  ws( 21, 41,  2) =            -0.5101685177691830
  ws( 22, 41,  2) =            -0.0929106141709990
  ws( 23, 41,  2) =             1.0132006574508501
  ws( 24, 41,  2) =             0.9185211735744240
  ws( 25, 41,  2) =             0.4543087070649110
  ws( 26, 41,  2) =            -0.1207982952488200
  ws( 27, 41,  2) =             0.7357157266788070
  ws( 28, 41,  2) =            -0.0709784392968673
  ws( 29, 41,  2) =             0.6633279232677290
  ws( 30, 41,  2) =            -0.1701021275187040
  ws( 31, 41,  2) =             0.2877321310825830
  ws( 32, 41,  2) =             0.2352883142331620
  ws( 33, 41,  2) =             0.8030217734854490
  ws( 34, 41,  2) =             0.5386909297313430
  ws( 35, 41,  2) =             0.2730034206834740
  ws( 36, 41,  2) =            -0.6599614720730370
  ws( 37, 41,  2) =            -0.7764427245879940
  ws( 38, 41,  2) =            -0.5198642364559410
  ws( 39, 41,  2) =            -0.0104019015566922
  ws( 40, 41,  2) =            -0.8776640409832760
  ws( 41, 41,  2) =            -0.9181536734604450
  ws( 42, 41,  2) =            -0.9295499892031880
  ws( 43, 41,  2) =            -0.7965154216787840
  ws( 44, 41,  2) =             0.7834487702944670
  ws( 45, 41,  2) =             0.0584469923316629
  ws( 46, 41,  2) =            -0.0968204169688437
  ws( 47, 41,  2) =            -0.1896695711525160
  ws( 48, 41,  2) =             0.2733954675283820
  ws( 49, 41,  2) =            -0.5260654287518620
  ws( 50, 41,  2) =            -0.9023219865608680
  ws(  1, 42,  2) =             0.7350709476173610
  ws(  2, 42,  2) =             0.6244403824443350
  ws(  3, 42,  2) =             0.1290017269204490
  ws(  4, 42,  2) =            -0.4538593771008340
  ws(  5, 42,  2) =             0.6625630740331609
  ws(  6, 42,  2) =            -0.6236902543412880
  ws(  7, 42,  2) =            -0.2353421677562320
  ws(  8, 42,  2) =             0.8030808794699540
  ws(  9, 42,  2) =             0.0151206731030566
  ws( 10, 42,  2) =            -0.2673191591356130
  ws( 11, 42,  2) =             0.5810125100750940
  ws( 12, 42,  2) =            -0.3013903479469480
  ws( 13, 42,  2) =            -1.3768702046092600
  ws( 14, 42,  2) =             0.9790206736844880
  ws( 15, 42,  2) =            -0.0275366278991593
  ws( 16, 42,  2) =            -0.0556102511258796
  ws( 17, 42,  2) =             0.2169614154209870
  ws( 18, 42,  2) =             0.9312400867961880
  ws( 19, 42,  2) =             0.5855526819201500
  ws( 20, 42,  2) =             0.9834710462682070
  ws( 21, 42,  2) =            -0.0275246468462982
  ws( 22, 42,  2) =            -0.3327549055273920
  ws( 23, 42,  2) =             0.4496444766258670
  ws( 24, 42,  2) =            -1.1728311819750601
  ws( 25, 42,  2) =             0.0007567679316548
  ws( 26, 42,  2) =             0.0771409960793273
  ws( 27, 42,  2) =             0.2997946712064420
  ws( 28, 42,  2) =            -0.5098689854352650
  ws( 29, 42,  2) =            -0.1218917650966590
  ws( 30, 42,  2) =             0.5069803005970650
  ws( 31, 42,  2) =            -0.4475438501701190
  ws( 32, 42,  2) =             0.3008968836617490
  ws( 33, 42,  2) =            -1.0524352037914799
  ws( 34, 42,  2) =             0.3384458918880790
  ws( 35, 42,  2) =             0.7875160543057250
  ws( 36, 42,  2) =             1.1559514624713700
  ws( 37, 42,  2) =             0.7484898574365890
  ws( 38, 42,  2) =             0.3002712937458360
  ws( 39, 42,  2) =             0.0574680310293019
  ws( 40, 42,  2) =             0.8208612405185109
  ws( 41, 42,  2) =            -0.2867172848157040
  ws( 42, 42,  2) =            -0.4650631325202240
  ws( 43, 42,  2) =             0.3947506496121870
  ws( 44, 42,  2) =             0.4754333874702730
  ws( 45, 42,  2) =             0.9879185117002350
  ws( 46, 42,  2) =             0.1760345701236050
  ws( 47, 42,  2) =             0.5119076292011610
  ws( 48, 42,  2) =            -0.1089486241241020
  ws( 49, 42,  2) =             0.3837592096471620
  ws( 50, 42,  2) =            -0.8628511274675300
  ws(  1, 43,  2) =             0.5743569273080330
  ws(  2, 43,  2) =            -0.2501111986173780
  ws(  3, 43,  2) =             0.0197235772346624
  ws(  4, 43,  2) =            -0.2793044834186780
  ws(  5, 43,  2) =             0.2133910117568670
  ws(  6, 43,  2) =            -1.1344650325910099
  ws(  7, 43,  2) =            -0.9461106989267080
  ws(  8, 43,  2) =            -1.7186262504606600
  ws(  9, 43,  2) =            -0.0348400048027441
  ws( 10, 43,  2) =            -0.3911039515143060
  ws( 11, 43,  2) =            -0.6758741300714250
  ws( 12, 43,  2) =             0.7323441441112520
  ws( 13, 43,  2) =             0.5060011018362890
  ws( 14, 43,  2) =            -0.6822897454944220
  ws( 15, 43,  2) =            -0.2065697050009720
  ws( 16, 43,  2) =            -0.9404973002800160
  ws( 17, 43,  2) =             0.5605158598353930
  ws( 18, 43,  2) =            -0.1497129609764720
  ws( 19, 43,  2) =             0.9367933119902030
  ws( 20, 43,  2) =            -2.1613863372065500
  ws( 21, 43,  2) =            -1.7444095802390300
  ws( 22, 43,  2) =            -0.8569385158716710
  ws( 23, 43,  2) =            -1.0433225805245401
  ws( 24, 43,  2) =             0.0351101053690882
  ws( 25, 43,  2) =             0.8315641436935070
  ws( 26, 43,  2) =            -0.8456478273656680
  ws( 27, 43,  2) =            -0.6124468620028070
  ws( 28, 43,  2) =             0.5280762927012640
  ws( 29, 43,  2) =             1.0062440120861600
  ws( 30, 43,  2) =            -0.8336027133192310
  ws( 31, 43,  2) =            -0.4587577695130300
  ws( 32, 43,  2) =            -0.5401374369773090
  ws( 33, 43,  2) =             1.3128271632505999
  ws( 34, 43,  2) =             0.7617583300467961
  ws( 35, 43,  2) =             0.4419343470942000
  ws( 36, 43,  2) =            -0.8935822762460220
  ws( 37, 43,  2) =             0.0198484592714467
  ws( 38, 43,  2) =            -0.6088175441170280
  ws( 39, 43,  2) =            -0.1432696286697030
  ws( 40, 43,  2) =            -0.9264173992672500
  ws( 41, 43,  2) =            -0.7561168236057250
  ws( 42, 43,  2) =             0.2390035669241600
  ws( 43, 43,  2) =            -1.1505008122061600
  ws( 44, 43,  2) =            -0.1363792798048130
  ws( 45, 43,  2) =             0.7834105417412460
  ws( 46, 43,  2) =            -0.3218300008581210
  ws( 47, 43,  2) =            -0.6097424076866140
  ws( 48, 43,  2) =             1.0261616958669399
  ws( 49, 43,  2) =             0.6775891249071450
  ws( 50, 43,  2) =            -0.6208828600186870
  ws(  1, 44,  2) =            -0.9478516064236630
  ws(  2, 44,  2) =             0.7328647283595300
  ws(  3, 44,  2) =            -0.3559558101354870
  ws(  4, 44,  2) =             0.7477529536974220
  ws(  5, 44,  2) =            -0.3590757675819360
  ws(  6, 44,  2) =            -0.8606745939575871
  ws(  7, 44,  2) =            -0.3058685190029150
  ws(  8, 44,  2) =             0.3886158066431570
  ws(  9, 44,  2) =            -0.4686799295739040
  ws( 10, 44,  2) =            -0.7486769876972900
  ws( 11, 44,  2) =            -1.0238875865272199
  ws( 12, 44,  2) =            -0.4947211325992140
  ws( 13, 44,  2) =            -0.9412153734871620
  ws( 14, 44,  2) =             0.1091414179897100
  ws( 15, 44,  2) =            -1.1126818945170900
  ws( 16, 44,  2) =            -1.0906375303973199
  ws( 17, 44,  2) =             0.3558758092023770
  ws( 18, 44,  2) =             0.7061833510305700
  ws( 19, 44,  2) =             1.1661879827116599
  ws( 20, 44,  2) =            -2.4340521670569202
  ws( 21, 44,  2) =            -0.9477726148414300
  ws( 22, 44,  2) =            -1.1385603885729700
  ws( 23, 44,  2) =             0.1607854881219180
  ws( 24, 44,  2) =            -0.5095583743802931
  ws( 25, 44,  2) =            -0.4860503548034930
  ws( 26, 44,  2) =             0.2966947553631310
  ws( 27, 44,  2) =            -1.5666991464650699
  ws( 28, 44,  2) =             0.1897549247006380
  ws( 29, 44,  2) =             0.9799966502734350
  ws( 30, 44,  2) =             0.3972821787885440
  ws( 31, 44,  2) =            -0.4917754165585620
  ws( 32, 44,  2) =            -1.4883469658909600
  ws( 33, 44,  2) =             0.8954870390955210
  ws( 34, 44,  2) =            -0.3419434719864560
  ws( 35, 44,  2) =            -0.2593194753324800
  ws( 36, 44,  2) =            -0.2574695778340230
  ws( 37, 44,  2) =             0.6562457909846540
  ws( 38, 44,  2) =            -0.1978080883443980
  ws( 39, 44,  2) =             0.5535067493261420
  ws( 40, 44,  2) =            -1.7792028423335700
  ws( 41, 44,  2) =            -0.3171131048011060
  ws( 42, 44,  2) =             0.5660078453359970
  ws( 43, 44,  2) =            -1.0095354636321301
  ws( 44, 44,  2) =            -0.8661999553685120
  ws( 45, 44,  2) =             1.0459816635775900
  ws( 46, 44,  2) =             0.6596241992585320
  ws( 47, 44,  2) =             0.4752520603417570
  ws( 48, 44,  2) =            -0.0848314757537210
  ws( 49, 44,  2) =            -0.7885918180683830
  ws( 50, 44,  2) =             0.7822713026999361
  ws(  1, 45,  2) =            -1.1139074386820300
  ws(  2, 45,  2) =            -0.9366890033808090
  ws(  3, 45,  2) =             0.1091165869342830
  ws(  4, 45,  2) =            -0.0762697279039654
  ws(  5, 45,  2) =             0.3597034006942050
  ws(  6, 45,  2) =             0.0320386890466665
  ws(  7, 45,  2) =             0.3537220571059850
  ws(  8, 45,  2) =            -1.1575591163471799
  ws(  9, 45,  2) =            -0.7109175700166720
  ws( 10, 45,  2) =             0.2238945639562360
  ws( 11, 45,  2) =             0.5719763113810230
  ws( 12, 45,  2) =            -0.0004848303480604
  ws( 13, 45,  2) =            -0.6516897952436570
  ws( 14, 45,  2) =             1.0431575467962899
  ws( 15, 45,  2) =            -0.7197129526555290
  ws( 16, 45,  2) =            -0.4371187573860160
  ws( 17, 45,  2) =             0.0167663775006247
  ws( 18, 45,  2) =             0.0026650823661489
  ws( 19, 45,  2) =             0.4905560249528050
  ws( 20, 45,  2) =            -1.3379522451584700
  ws( 21, 45,  2) =            -1.7251788385771900
  ws( 22, 45,  2) =            -0.2124049084855860
  ws( 23, 45,  2) =            -0.5096796052955920
  ws( 24, 45,  2) =             0.6791750644814620
  ws( 25, 45,  2) =            -0.2536853128538780
  ws( 26, 45,  2) =            -0.4079811206572420
  ws( 27, 45,  2) =            -0.4406968570820460
  ws( 28, 45,  2) =             0.1576706566624800
  ws( 29, 45,  2) =            -0.5617823428251820
  ws( 30, 45,  2) =             1.2833054393206900
  ws( 31, 45,  2) =             0.7680828853203350
  ws( 32, 45,  2) =            -1.2886328083586001
  ws( 33, 45,  2) =             0.2113560343261840
  ws( 34, 45,  2) =             0.1744785895294820
  ws( 35, 45,  2) =            -0.1363760883995220
  ws( 36, 45,  2) =             1.0303909299238601
  ws( 37, 45,  2) =            -1.1791863305022099
  ws( 38, 45,  2) =             1.0806834693438900
  ws( 39, 45,  2) =             0.2724345535075090
  ws( 40, 45,  2) =            -0.8968011588744470
  ws( 41, 45,  2) =             1.0106133475425001
  ws( 42, 45,  2) =            -0.3377433516665010
  ws( 43, 45,  2) =            -1.9684666047041499
  ws( 44, 45,  2) =             0.7871226140830690
  ws( 45, 45,  2) =             0.4678033907953480
  ws( 46, 45,  2) =            -0.2968567009977090
  ws( 47, 45,  2) =             0.9658112834193980
  ws( 48, 45,  2) =             1.2668499169705900
  ws( 49, 45,  2) =             0.4226001141639440
  ws( 50, 45,  2) =            -0.4444158272228770
  ws(  1, 46,  2) =             0.1256381046241610
  ws(  2, 46,  2) =            -0.0582060664432944
  ws(  3, 46,  2) =            -0.4977164619385700
  ws(  4, 46,  2) =            -0.3462655230141750
  ws(  5, 46,  2) =            -0.1666601094209410
  ws(  6, 46,  2) =            -0.3247600936941830
  ws(  7, 46,  2) =             0.0636538852118209
  ws(  8, 46,  2) =            -0.1432723990552880
  ws(  9, 46,  2) =            -0.6209327203103520
  ws( 10, 46,  2) =            -0.1782694387496080
  ws( 11, 46,  2) =            -1.0015652649674101
  ws( 12, 46,  2) =            -0.7897886846046320
  ws( 13, 46,  2) =             0.6050962326800260
  ws( 14, 46,  2) =             0.6168450566245280
  ws( 15, 46,  2) =             0.1995617981168020
  ws( 16, 46,  2) =            -0.5819879703912880
  ws( 17, 46,  2) =            -0.8493057833125010
  ws( 18, 46,  2) =            -0.1717702451607010
  ws( 19, 46,  2) =             0.7922473413555190
  ws( 20, 46,  2) =            -1.8389553889446599
  ws( 21, 46,  2) =             0.0796308851604817
  ws( 22, 46,  2) =            -0.6615473322085680
  ws( 23, 46,  2) =             0.4574500123155660
  ws( 24, 46,  2) =             0.3895684445485210
  ws( 25, 46,  2) =            -1.0436509297460299
  ws( 26, 46,  2) =            -0.3732951050426540
  ws( 27, 46,  2) =             0.3749230977529990
  ws( 28, 46,  2) =            -0.8455238021494050
  ws( 29, 46,  2) =            -0.9976542034479750
  ws( 30, 46,  2) =             0.5932005047164690
  ws( 31, 46,  2) =            -0.0631140498880645
  ws( 32, 46,  2) =            -0.2271055919615860
  ws( 33, 46,  2) =             0.6585163958972250
  ws( 34, 46,  2) =             0.3482828949674610
  ws( 35, 46,  2) =            -0.0523571646721267
  ws( 36, 46,  2) =             0.0120359022959419
  ws( 37, 46,  2) =            -0.6161683751072210
  ws( 38, 46,  2) =             0.4293777646595640
  ws( 39, 46,  2) =            -0.6993664275677171
  ws( 40, 46,  2) =             0.3027536213296050
  ws( 41, 46,  2) =             0.8456522742223550
  ws( 42, 46,  2) =            -1.0045969617384900
  ws( 43, 46,  2) =            -1.3028184047882301
  ws( 44, 46,  2) =            -0.2216047488312000
  ws( 45, 46,  2) =             0.1755353922455910
  ws( 46, 46,  2) =             0.0302811604274713
  ws( 47, 46,  2) =             0.0283722262331667
  ws( 48, 46,  2) =             1.0823847919138001
  ws( 49, 46,  2) =             0.8705761302736600
  ws( 50, 46,  2) =            -1.0702053296374501
  ws(  1, 47,  2) =            -0.0541584894010633
  ws(  2, 47,  2) =            -0.6866336036736300
  ws(  3, 47,  2) =             0.2420311813873090
  ws(  4, 47,  2) =             0.8468199982512090
  ws(  5, 47,  2) =            -0.7723143910016370
  ws(  6, 47,  2) =            -0.3219205752009610
  ws(  7, 47,  2) =             0.4394093025101400
  ws(  8, 47,  2) =            -0.1156840253603700
  ws(  9, 47,  2) =            -0.2544056991149020
  ws( 10, 47,  2) =            -0.4603687420786490
  ws( 11, 47,  2) =             1.2462200941312400
  ws( 12, 47,  2) =             0.1040686964643150
  ws( 13, 47,  2) =             0.7816267489744130
  ws( 14, 47,  2) =             0.6885234993532090
  ws( 15, 47,  2) =             0.3425770704791350
  ws( 16, 47,  2) =             0.0919472457333207
  ws( 17, 47,  2) =             0.0971514734135521
  ws( 18, 47,  2) =            -0.6838048052992910
  ws( 19, 47,  2) =             0.2713150558057760
  ws( 20, 47,  2) =             1.0658648150856300
  ws( 21, 47,  2) =             1.1453330647388400
  ws( 22, 47,  2) =             1.4038115496750900
  ws( 23, 47,  2) =            -0.0833518734622076
  ws( 24, 47,  2) =            -0.9223303432124930
  ws( 25, 47,  2) =             0.9446626711656190
  ws( 26, 47,  2) =            -1.0055156017986999
  ws( 27, 47,  2) =             2.2777845274957400
  ws( 28, 47,  2) =             0.8203371127822791
  ws( 29, 47,  2) =             0.7922656089217770
  ws( 30, 47,  2) =            -0.3423103430281820
  ws( 31, 47,  2) =             0.7077460433683830
  ws( 32, 47,  2) =             0.6543319710439770
  ws( 33, 47,  2) =            -0.8208061303016220
  ws( 34, 47,  2) =            -0.1733846278261880
  ws( 35, 47,  2) =            -0.4792679438391450
  ws( 36, 47,  2) =            -0.3625475144003720
  ws( 37, 47,  2) =             1.1195824966148600
  ws( 38, 47,  2) =            -0.7362736000859540
  ws( 39, 47,  2) =             0.1746533133171140
  ws( 40, 47,  2) =             1.9673949108800000
  ws( 41, 47,  2) =             0.2445325607981160
  ws( 42, 47,  2) =            -0.6176609990831780
  ws( 43, 47,  2) =             0.3101648361997190
  ws( 44, 47,  2) =             0.8506147139883889
  ws( 45, 47,  2) =            -1.0541779706357399
  ws( 46, 47,  2) =            -0.1761817384593110
  ws( 47, 47,  2) =             0.0347577625836199
  ws( 48, 47,  2) =            -0.7274215558296220
  ws( 49, 47,  2) =             0.8386968155673240
  ws( 50, 47,  2) =            -0.4614362622469170
  ws(  1, 48,  2) =             0.0714339881286456
  ws(  2, 48,  2) =             0.3258428353663540
  ws(  3, 48,  2) =             0.7175338564347140
  ws(  4, 48,  2) =            -0.3546750609041400
  ws(  5, 48,  2) =            -0.3406118357373970
  ws(  6, 48,  2) =            -0.0139430567419437
  ws(  7, 48,  2) =             0.3442187429187410
  ws(  8, 48,  2) =             0.6387550617032201
  ws(  9, 48,  2) =            -0.6385785749429440
  ws( 10, 48,  2) =             0.4570312176313270
  ws( 11, 48,  2) =             0.0532055633980784
  ws( 12, 48,  2) =             0.4778302993282710
  ws( 13, 48,  2) =            -0.7592350022363610
  ws( 14, 48,  2) =            -0.2006850478456820
  ws( 15, 48,  2) =            -0.9786936571526530
  ws( 16, 48,  2) =             0.1675632161070280
  ws( 17, 48,  2) =            -0.1303560929588010
  ws( 18, 48,  2) =             0.6898873355078901
  ws( 19, 48,  2) =            -0.4854466703534110
  ws( 20, 48,  2) =            -0.9240380185608390
  ws( 21, 48,  2) =            -1.0599556622602500
  ws( 22, 48,  2) =            -1.2295240705926500
  ws( 23, 48,  2) =             0.6770937295737450
  ws( 24, 48,  2) =             0.4635312328711110
  ws( 25, 48,  2) =             0.7421907999289700
  ws( 26, 48,  2) =            -0.6076115393240999
  ws( 27, 48,  2) =             0.3358189854491210
  ws( 28, 48,  2) =             0.6298679875818430
  ws( 29, 48,  2) =             0.7535507483225080
  ws( 30, 48,  2) =            -0.1351547861605080
  ws( 31, 48,  2) =            -0.1411563600780240
  ws( 32, 48,  2) =            -0.7911751888342790
  ws( 33, 48,  2) =             0.2251328029152030
  ws( 34, 48,  2) =            -0.1129103175957850
  ws( 35, 48,  2) =            -0.4594373583603420
  ws( 36, 48,  2) =            -0.6144049592899620
  ws( 37, 48,  2) =            -0.6074966237753660
  ws( 38, 48,  2) =            -0.4798474992378780
  ws( 39, 48,  2) =            -0.3150702602509020
  ws( 40, 48,  2) =            -0.2820836984583010
  ws( 41, 48,  2) =            -0.1630779479172350
  ws( 42, 48,  2) =            -1.2352136050118301
  ws( 43, 48,  2) =            -0.5654622232858700
  ws( 44, 48,  2) =            -0.1222856472521520
  ws( 45, 48,  2) =             1.3059322338309600
  ws( 46, 48,  2) =            -0.9483667174889230
  ws( 47, 48,  2) =            -0.6336379863399990
  ws( 48, 48,  2) =             1.2229484810472300
  ws( 49, 48,  2) =            -0.2408547125571190
  ws( 50, 48,  2) =             0.6104980053326340
  ws(  1, 49,  2) =             1.0694060465356801
  ws(  2, 49,  2) =            -0.9177643114568940
  ws(  3, 49,  2) =            -0.4840030804492820
  ws(  4, 49,  2) =            -0.7028462396458710
  ws(  5, 49,  2) =            -0.5258385213204650
  ws(  6, 49,  2) =            -1.0428047861385199
  ws(  7, 49,  2) =             0.5783619679092180
  ws(  8, 49,  2) =             1.4027930641154500
  ws(  9, 49,  2) =            -0.7597228211850390
  ws( 10, 49,  2) =             0.7502242932940389
  ws( 11, 49,  2) =             1.4227287934531001
  ws( 12, 49,  2) =             0.1262833434478610
  ws( 13, 49,  2) =             1.0506119853553599
  ws( 14, 49,  2) =            -0.7983048655807931
  ws( 15, 49,  2) =             0.3809023559275310
  ws( 16, 49,  2) =             0.0440911059750375
  ws( 17, 49,  2) =            -0.0427649694881873
  ws( 18, 49,  2) =            -0.9920085374322600
  ws( 19, 49,  2) =            -1.0465737821574099
  ws( 20, 49,  2) =             2.7200852610971200
  ws( 21, 49,  2) =             1.1462100256721801
  ws( 22, 49,  2) =             1.6101895642078601
  ws( 23, 49,  2) =            -0.4982569512361820
  ws( 24, 49,  2) =            -0.0711894756251097
  ws( 25, 49,  2) =             0.8673076843710090
  ws( 26, 49,  2) =             0.9292144431193951
  ws( 27, 49,  2) =             0.6676415434796210
  ws( 28, 49,  2) =            -0.3321193915175040
  ws( 29, 49,  2) =             0.6494075515785520
  ws( 30, 49,  2) =            -0.6651528373896680
  ws( 31, 49,  2) =            -0.1716599814462670
  ws( 32, 49,  2) =             1.1408369890586301
  ws( 33, 49,  2) =             0.4339663801951460
  ws( 34, 49,  2) =             0.0493875216276905
  ws( 35, 49,  2) =             0.5534078972880910
  ws( 36, 49,  2) =            -1.0449178101584600
  ws( 37, 49,  2) =             1.2063419805183999
  ws( 38, 49,  2) =             0.5724209830092430
  ws( 39, 49,  2) =            -0.5196792861609510
  ws( 40, 49,  2) =             0.7160309922858950
  ws( 41, 49,  2) =            -0.6438340206824520
  ws( 42, 49,  2) =             0.4676671722077620
  ws( 43, 49,  2) =             0.6639099014871530
  ws( 44, 49,  2) =            -0.6428358343867649
  ws( 45, 49,  2) =             0.2888674495271200
  ws( 46, 49,  2) =             0.1452874799184060
  ws( 47, 49,  2) =             0.2017857186214320
  ws( 48, 49,  2) =            -0.9885914193736640
  ws( 49, 49,  2) =             0.8537800267469779
  ws( 50, 49,  2) =             0.5379583938044999
  ws(  1, 50,  2) =            -1.5949137207806601
  ws(  2, 50,  2) =             0.7082283053206661
  ws(  3, 50,  2) =             0.8360066774314820
  ws(  4, 50,  2) =            -0.2200175984929010
  ws(  5, 50,  2) =            -0.8466734109302120
  ws(  6, 50,  2) =            -1.4955305028968200
  ws(  7, 50,  2) =             1.0239050004710299
  ws(  8, 50,  2) =            -5.0917789988357001
  ws(  9, 50,  2) =             0.0305385627073178
  ws( 10, 50,  2) =             1.3270259436364600
  ws( 11, 50,  2) =            -0.3647720977030940
  ws( 12, 50,  2) =            -0.9386238232740260
  ws( 13, 50,  2) =             2.0172900454913600
  ws( 14, 50,  2) =             1.8378662420782499
  ws( 15, 50,  2) =            -3.4168841328021000
  ws( 16, 50,  2) =            -0.0541001709237797
  ws( 17, 50,  2) =             0.1130664205062560
  ws( 18, 50,  2) =             0.5566117803769070
  ws( 19, 50,  2) =            -1.6491822511622101
  ws( 20, 50,  2) =            -0.5625841111055000
  ws( 21, 50,  2) =             3.7339010606868399
  ws( 22, 50,  2) =            -1.9118008164844200
  ws( 23, 50,  2) =             0.0269529828557297
  ws( 24, 50,  2) =             0.4963132546784370
  ws( 25, 50,  2) =             0.9497631850065410
  ws( 26, 50,  2) =             0.4298718781672210
  ws( 27, 50,  2) =             6.0130100154489998
  ws( 28, 50,  2) =             0.2751953959948140
  ws( 29, 50,  2) =             1.2667089123766400
  ws( 30, 50,  2) =            -1.0856273262675100
  ws( 31, 50,  2) =             0.0348253086735460
  ws( 32, 50,  2) =             1.1527374404768500
  ws( 33, 50,  2) =             0.1399511886342670
  ws( 34, 50,  2) =            -0.4722532143463310
  ws( 35, 50,  2) =            -1.7148429423350799
  ws( 36, 50,  2) =             0.9464326695170699
  ws( 37, 50,  2) =            -0.3296850238937610
  ws( 38, 50,  2) =            -0.8363177123562560
  ws( 39, 50,  2) =            -0.0484152109173687
  ws( 40, 50,  2) =             0.2666777887275450
  ws( 41, 50,  2) =             0.6806461233167380
  ws( 42, 50,  2) =            -0.6376257006584360
  ws( 43, 50,  2) =             0.3516302988896170
  ws( 44, 50,  2) =             0.8505263739893980
  ws( 45, 50,  2) =            -1.0454383196541801
  ws( 46, 50,  2) =             0.5155008433445331
  ws( 47, 50,  2) =             0.1532478552275280
  ws( 48, 50,  2) =            -2.1946289717820799
  ws( 49, 50,  2) =            -1.1449317378233901
  ws( 50, 50,  2) =             1.2033474969861599
  ws(  1,  1,  3) =            -0.7889412106321360
  ws(  1,  2,  3) =             0.1326059115847710
  ws(  1,  3,  3) =            -0.5323251763480100
  ws(  1,  4,  3) =             0.9397975361995810
  ws(  1,  5,  3) =            -0.9423964750564440
  ws(  1,  6,  3) =            -0.9455750651095360
  ws(  1,  7,  3) =            -0.7693803152244690
  ws(  1,  8,  3) =             2.9880463072088501
  ws(  1,  9,  3) =            -0.0549434480549020
  ws(  1, 10,  3) =             1.5075615885011000
  ws(  1, 11,  3) =             1.7190710833149201
  ws(  1, 12,  3) =            -0.9713590575952190
  ws(  1, 13,  3) =            -1.3395040196095700
  ws(  1, 14,  3) =            -2.1921009766127799
  ws(  1, 15,  3) =            -4.3656610939966596
  ws(  1, 16,  3) =            -0.8834860938348030
  ws(  1, 17,  3) =             0.8618838338688249
  ws(  1, 18,  3) =             0.4852544157339590
  ws(  1, 19,  3) =            -2.9162396522414298
  ws(  1, 20,  3) =            -3.9045170594998799
  ws(  1, 21,  3) =             3.9895071758962799
  ws(  1, 22,  3) =             2.2522594915990801
  ws(  1, 23,  3) =            -0.9637873256386780
  ws(  1, 24,  3) =             1.0364920663001200
  ws(  1, 25,  3) =            -1.4843066171521999
  ws(  1, 26,  3) =            -0.1549486995807850
  ws(  1, 27,  3) =             5.8196678229160401
  ws(  1, 28,  3) =            -0.0996950183496838
  ws(  1, 29,  3) =             2.3244184346586398
  ws(  1, 30,  3) =             2.5302142765939801
  ws(  1, 31,  3) =            -0.7875677768981451
  ws(  1, 32,  3) =            -3.3949861569489701
  ws(  1, 33,  3) =            -2.2601680054351898
  ws(  1, 34,  3) =             0.8047662914917240
  ws(  1, 35,  3) =            -1.8212479981207399
  ws(  1, 36,  3) =             1.5826574293087301
  ws(  1, 37,  3) =             1.4301975575075800
  ws(  1, 38,  3) =            -0.2257539687297130
  ws(  1, 39,  3) =            -0.2428450395036370
  ws(  1, 40,  3) =             6.6291355923215303
  ws(  1, 41,  3) =             1.2934278191571000
  ws(  1, 42,  3) =            -1.7547904451804499
  ws(  1, 43,  3) =            -2.8041260563720400
  ws(  1, 44,  3) =            -0.5965323657329250
  ws(  1, 45,  3) =             3.1726763985090800
  ws(  1, 46,  3) =            -0.0884792253142907
  ws(  1, 47,  3) =            -0.4222194823742070
  ws(  1, 48,  3) =             2.1211675125533000
  ws(  1, 49,  3) =            -1.9044556248636000
  ws(  1, 50,  3) =             1.2499418271608900
  bs(  1,  1) =            -0.5996329182680650
  bs(  2,  1) =            -0.0027125481720047
  bs(  3,  1) =             1.1846700149878899
  bs(  4,  1) =             0.3615491210390700
  bs(  5,  1) =             0.1233243680958740
  bs(  6,  1) =            -0.4149020478334650
  bs(  7,  1) =            -0.4633406059576440
  bs(  8,  1) =            -0.0349368418626486
  bs(  9,  1) =            -1.0971864479496101
  bs( 10,  1) =             0.0972942386499917
  bs( 11,  1) =            -0.1827356513222850
  bs( 12,  1) =            -1.4044238474916000
  bs( 13,  1) =            -0.1955868655170370
  bs( 14,  1) =             0.6779646379526210
  bs( 15,  1) =             0.2072034996795800
  bs( 16,  1) =            -0.0483153753580529
  bs( 17,  1) =            -1.0923166634494701
  bs( 18,  1) =            -0.8362869007869380
  bs( 19,  1) =             0.2831897558673200
  bs( 20,  1) =             0.2546768958687170
  bs( 21,  1) =            -0.8096226555961960
  bs( 22,  1) =            -0.9581207435806171
  bs( 23,  1) =            -0.2224119551774180
  bs( 24,  1) =            -0.4711334078774830
  bs( 25,  1) =            -0.8996777501032680
  bs( 26,  1) =            -0.0199844770337956
  bs( 27,  1) =            -0.3441921359528430
  bs( 28,  1) =            -0.5588532116098009
  bs( 29,  1) =            -0.9101979131662380
  bs( 30,  1) =             0.8927846150858580
  bs( 31,  1) =             0.0227996650682047
  bs( 32,  1) =            -0.7813947596493430
  bs( 33,  1) =            -0.7067602668868360
  bs( 34,  1) =             0.0157202678627658
  bs( 35,  1) =            -1.3622280817815600
  bs( 36,  1) =            -0.3440434833292880
  bs( 37,  1) =            -0.8379324931682250
  bs( 38,  1) =            -0.5989056725780501
  bs( 39,  1) =            -0.0547564825634197
  bs( 40,  1) =            -0.3200795143181890
  bs( 41,  1) =            -0.3975692014550770
  bs( 42,  1) =            -0.2976925608653880
  bs( 43,  1) =             0.0259721907258123
  bs( 44,  1) =             1.0183331607811901
  bs( 45,  1) =            -0.0654926212679164
  bs( 46,  1) =             1.0923516774402300
  bs( 47,  1) =            -0.0982611244329327
  bs( 48,  1) =            -0.0338850711651895
  bs( 49,  1) =             0.8597712669875370
  bs( 50,  1) =            -2.0774864010866998
  bs(  1,  2) =             0.0132568224931650
  bs(  2,  2) =            -0.8673559057012530
  bs(  3,  2) =            -0.1088168170102440
  bs(  4,  2) =             0.4714992661319060
  bs(  5,  2) =             0.2356752541395180
  bs(  6,  2) =            -0.2080139468939570
  bs(  7,  2) =            -0.2412732096662170
  bs(  8,  2) =             0.6943334796756420
  bs(  9,  2) =            -0.5131855068452860
  bs( 10,  2) =            -0.6817308084580880
  bs( 11,  2) =             0.1564941863071350
  bs( 12,  2) =            -0.7481830092378200
  bs( 13,  2) =             0.7524453272959470
  bs( 14,  2) =             0.2390463777810880
  bs( 15,  2) =             0.2799320013157160
  bs( 16,  2) =             0.2342889424582510
  bs( 17,  2) =            -0.9793587889479880
  bs( 18,  2) =             0.8305873009728070
  bs( 19,  2) =            -0.0025872697109366
  bs( 20,  2) =            -0.2155199722132290
  bs( 21,  2) =            -0.7895039179018430
  bs( 22,  2) =            -0.5910937213395679
  bs( 23,  2) =             0.0715154972094770
  bs( 24,  2) =             0.4581507095455220
  bs( 25,  2) =            -0.4445699143994600
  bs( 26,  2) =            -0.1035741239550130
  bs( 27,  2) =             0.4229449109576390
  bs( 28,  2) =            -0.1793113659540640
  bs( 29,  2) =            -0.4841033661306050
  bs( 30,  2) =            -0.7394052115947920
  bs( 31,  2) =            -0.2287221605525120
  bs( 32,  2) =            -0.5286075564466660
  bs( 33,  2) =             0.3450172623346300
  bs( 34,  2) =             1.0226874490278000
  bs( 35,  2) =            -0.3413621836744740
  bs( 36,  2) =            -0.9034344096932000
  bs( 37,  2) =            -0.2992839034423640
  bs( 38,  2) =             0.0134704173943164
  bs( 39,  2) =            -0.7704566800573620
  bs( 40,  2) =             0.2666584966407330
  bs( 41,  2) =             0.2989865673050790
  bs( 42,  2) =             1.1764343759525200
  bs( 43,  2) =            -0.5292582974039940
  bs( 44,  2) =             0.6522313048158630
  bs( 45,  2) =             0.9114535384672970
  bs( 46,  2) =             0.3730202436108410
  bs( 47,  2) =             0.8872267720959700
  bs( 48,  2) =             0.8966612584215951
  bs( 49,  2) =             0.8119447095511010
  bs( 50,  2) =             0.1556250831527140
  bs(  1,  3) =            -0.2580830475104820
  do i=1,nnst(0)
    as(i,0)=(r(i)-xmin(i))/(xmax(i)-xmin(i))*2.d0-1.d0
  enddo
  das=0.d0
  do i=1,nnst(0)
    das(i,i,0)=1.d0
  enddo
  do m=1,nnlr
    do i=1,nnst(m)
      an=0.d0
      do j=1,nnst(m-1)
        an=an+ws(i,j,m)*as(j,m-1)
      enddo
      ns=an+bs(i,m)
      if (m .lt. nnlr)then
        call nn_tranf(ns,y)
        as(i,m)=y
      else
        as(i,m)=ns
      endif
      if (idg .eq. 1)then
        do j=1,nnst(0)
          an=0.d0
          do k=1,nnst(m-1)
            an=an+ws(i,k,m)*das(k,j,m-1)
          enddo
          dns=an
          if (m .lt. nnlr)then
            call nn_dtranf(ns,dy)
            das(i,j,m)=dy*dns
          else
            das(i,j,m)=dns
          endif
        enddo
      endif
    enddo
  enddo
  do i=1,nnst(nnlr)
    v(i)=(as(i,nnlr)+1.d0)*(ymax(i)-ymin(i))/2.d0+ymin(i)
  enddo
  if (idg .eq. 1)then
    do j=1,nnst(0)
      do i=1,nnst(nnlr)
        dv(i,j)=das(i,j,nnlr)*(ymax(i)-ymin(i))/(xmax(j)-xmin(j))
      enddo
    enddo
  endif
  return
  end subroutine
  
  subroutine nn_tranf(x,y)
  implicit none
  real*8,intent(in) :: x
  real*8,intent(out) :: y
  y=dtanh(x)
  return
  end subroutine
  subroutine nn_dtranf(x,dy)
  implicit none
  real*8,intent(in) :: x
  real*8,intent(out) :: dy
  real*8 :: y
  y=dtanh(x)
  dy=1.d0-y*y
  return
  end subroutine
